
/* SCHEME->C */

#include <objects.h>

void scrt7__init();
DEFCSTRING( t4554, "." );
DEFSTATICTSCP( c4097 );
DEFSTATICTSCP( c4090 );
DEFSTATICTSCP( c3872 );
DEFSTATICTSCP( c3824 );
DEFSTATICTSCP( c3743 );
DEFSTATICTSCP( c3711 );
DEFCSTRING( t4556, "#\\space" );
DEFSTATICTSCP( t4555 );
DEFCSTRING( t4558, "#\\return" );
DEFSTATICTSCP( t4557 );
DEFCSTRING( t4560, "#\\formfeed" );
DEFSTATICTSCP( t4559 );
DEFCSTRING( t4562, "#\\linefeed" );
DEFSTATICTSCP( t4561 );
DEFCSTRING( t4564, "#\\newline" );
DEFSTATICTSCP( t4563 );
DEFCSTRING( t4566, "#\\tab" );
DEFSTATICTSCP( t4565 );
DEFCSTRING( t4567, "#\\???" );
DEFSTATICTSCP( c3700 );
DEFSTATICTSCP( c3696 );
DEFSTATICTSCP( c3688 );
DEFCSTRING( t4568, " ...)" );
DEFSTATICTSCP( c3676 );
DEFCSTRING( t4569, ")" );
DEFSTATICTSCP( c3675 );
DEFCSTRING( t4570, " . " );
DEFSTATICTSCP( c3674 );
DEFCSTRING( t4571, " " );
DEFSTATICTSCP( c3654 );
DEFCSTRING( t4572, "..." );
DEFSTATICTSCP( c3596 );
DEFSTATICTSCP( c3595 );
DEFCSTRING( t4574, ",@" );
DEFSTATICTSCP( t4573 );
DEFSTATICTSCP( t4575 );
DEFCSTRING( t4577, "," );
DEFSTATICTSCP( t4576 );
DEFSTATICTSCP( t4578 );
DEFCSTRING( t4580, "`" );
DEFSTATICTSCP( t4579 );
DEFSTATICTSCP( t4581 );
DEFCSTRING( t4583, "'" );
DEFSTATICTSCP( t4582 );
DEFSTATICTSCP( t4584 );
DEFCSTRING( t4585, "(...)" );
DEFSTATICTSCP( c3561 );
DEFCSTRING( t4586, "(" );
DEFSTATICTSCP( c3456 );
DEFSTATICTSCP( c3424 );
DEFSTATICTSCP( t4587 );
DEFSTATICTSCP( t4588 );
DEFCSTRING( t4589, "Argument is not a SYMBOL: ~s" );
DEFSTATICTSCP( c3423 );
DEFSTATICTSCP( c3422 );
DEFCSTRING( t4590, "#" );
DEFSTATICTSCP( c3397 );
DEFCSTRING( t4591, "#T" );
DEFSTATICTSCP( c3394 );
DEFCSTRING( t4592, "#F" );
DEFSTATICTSCP( c3393 );
DEFCSTRING( t4593, "()" );
DEFSTATICTSCP( c3392 );
DEFCSTRING( t4594, "#*END-OF-FILE*" );
DEFSTATICTSCP( c3391 );
DEFCSTRING( t4595, "#*UNDEFINED*" );
DEFSTATICTSCP( c3390 );
DEFCSTRING( t4596, "#*PROCEDURE*" );
DEFSTATICTSCP( c3389 );
DEFSTATICTSCP( c3388 );
DEFSTATICTSCP( c3387 );
DEFCSTRING( t4597, "#*??????*" );
DEFSTATICTSCP( c3359 );
DEFCSTRING( t4598, "Argument is not a STRING: ~s" );
DEFSTATICTSCP( c3258 );
DEFSTATICTSCP( c3257 );
DEFSTATICTSCP( c3219 );
DEFSTATICTSCP( c3218 );
DEFSTATICTSCP( c3217 );
DEFSTATICTSCP( c3213 );
DEFSTATICTSCP( c3212 );
DEFSTATICTSCP( c3211 );
DEFCSTRING( t4599, "Poorly formed LIST" );
DEFSTATICTSCP( c3192 );
DEFSTATICTSCP( c3168 );
DEFCSTRING( t4600, "Poorly formed DATUM: ~s" );
DEFSTATICTSCP( c3167 );
DEFSTATICTSCP( c3113 );
DEFSTATICTSCP( c3112 );
DEFSTATICTSCP( c3105 );
DEFCSTRING( t4601, "Argument is not an FIXED: ~s" );
DEFSTATICTSCP( c3104 );
DEFSTATICTSCP( c3103 );
DEFCSTRING( t4602, "Argument is out of range: ~s" );
DEFSTATICTSCP( c2981 );
DEFCSTRING( t4603, "Argument is not a FLOAT: ~s" );
DEFSTATICTSCP( c2976 );
DEFSTATICTSCP( c2975 );
DEFSTATICTSCP( c2946 );
DEFCSTRING( t4604, "Illegal floating point number: ~a" );
DEFSTATICTSCP( c2936 );
DEFCSTRING( t4605, "Floating point numbers must be base 10: ~a" );
DEFSTATICTSCP( c2933 );
DEFCSTRING( t4606, "Illegal digit(s) in integer: ~a" );
DEFSTATICTSCP( c2929 );
DEFCSTRING( t4607, "Invalid number base: ~a" );
DEFSTATICTSCP( c2833 );
DEFSTATICTSCP( c2832 );
DEFSTATICTSCP( c2831 );
DEFSTATICTSCP( c2830 );
DEFSTATICTSCP( c2829 );
DEFSTATICTSCP( c2766 );
DEFSTATICTSCP( c2724 );
DEFCSTRING( t4608, "Index is not in bounds: ~s" );
DEFSTATICTSCP( c2610 );
DEFCSTRING( t4609, "Argument is not an INTEGER: ~s" );
DEFSTATICTSCP( c2606 );
DEFCSTRING( t4610, "Argument is not a VECTOR: ~s" );
DEFSTATICTSCP( c2603 );
DEFSTATICTSCP( c2602 );
DEFCSTRING( t4611, "Argument not an unsigned 8-bit INTEGER: ~s" );
DEFSTATICTSCP( c2456 );
DEFSTATICTSCP( c2455 );
DEFCSTRING( t4612, "Unrecognized CHARACTER NAME: ~s" );
DEFSTATICTSCP( c2429 );
DEFSTATICTSCP( c2428 );
DEFSTATICTSCP( c2424 );
DEFSTATICTSCP( c2420 );
DEFSTATICTSCP( c2416 );
DEFSTATICTSCP( c2412 );
DEFSTATICTSCP( c2408 );
DEFSTATICTSCP( c2354 );
DEFCSTRING( t4613, "Invalid # option: ~a" );
DEFSTATICTSCP( c2323 );
DEFSTATICTSCP( c2256 );
DEFSTATICTSCP( c2228 );
DEFCSTRING( t4614, "Argument(s) not CHAR: ~s ~s" );
DEFSTATICTSCP( c2175 );
DEFSTATICTSCP( c2174 );
DEFCSTRING( t4615, "Unexpected end-of-file" );
DEFSTATICTSCP( c2156 );
DEFSTATICTSCP( c2155 );
DEFSTATICTSCP( c2147 );
DEFSTATICTSCP( c2145 );
DEFSTATICTSCP( c2143 );
DEFSTATICTSCP( c2141 );
DEFSTATICTSCP( c2139 );
DEFSTATICTSCP( c2137 );
DEFSTATICTSCP( c2135 );
DEFSTATICTSCP( c2133 );
DEFSTATICTSCP( c2131 );

static void  init_constants()
{
        TSCP  X1;

        c4097 = CSTRING_TSCP( t4554 );
        CONSTANTEXP( ADR( c4097 ) );
        c4090 = EMPTYLIST;
        c4090 = CONS( _TSCP( 25874 ), c4090 );
        c4090 = CONS( _TSCP( 11794 ), c4090 );
        CONSTANTEXP( ADR( c4090 ) );
        c3872 = EMPTYLIST;
        c3872 = CONS( _TSCP( 11538 ), c3872 );
        c3872 = CONS( _TSCP( 11026 ), c3872 );
        c3872 = CONS( _TSCP( 11794 ), c3872 );
        CONSTANTEXP( ADR( c3872 ) );
        c3824 = EMPTYLIST;
        c3824 = CONS( _TSCP( 8722 ), c3824 );
        CONSTANTEXP( ADR( c3824 ) );
        c3743 = STRINGTOSYMBOL( CSTRING_TSCP( "STRING-REF" ) );
        CONSTANTEXP( ADR( c3743 ) );
        c3711 = EMPTYLIST;
        X1 = EMPTYLIST;
        t4555 = CSTRING_TSCP( t4556 );
        X1 = CONS( t4555, X1 );
        X1 = CONS( _TSCP( 8210 ), X1 );
        c3711 = CONS( X1, c3711 );
        X1 = EMPTYLIST;
        t4557 = CSTRING_TSCP( t4558 );
        X1 = CONS( t4557, X1 );
        X1 = CONS( _TSCP( 3346 ), X1 );
        c3711 = CONS( X1, c3711 );
        X1 = EMPTYLIST;
        t4559 = CSTRING_TSCP( t4560 );
        X1 = CONS( t4559, X1 );
        X1 = CONS( _TSCP( 3090 ), X1 );
        c3711 = CONS( X1, c3711 );
        X1 = EMPTYLIST;
        t4561 = CSTRING_TSCP( t4562 );
        X1 = CONS( t4561, X1 );
        X1 = CONS( _TSCP( 2578 ), X1 );
        c3711 = CONS( X1, c3711 );
        X1 = EMPTYLIST;
        t4563 = CSTRING_TSCP( t4564 );
        X1 = CONS( t4563, X1 );
        X1 = CONS( _TSCP( 2578 ), X1 );
        c3711 = CONS( X1, c3711 );
        X1 = EMPTYLIST;
        t4565 = CSTRING_TSCP( t4566 );
        X1 = CONS( t4565, X1 );
        X1 = CONS( _TSCP( 2322 ), X1 );
        c3711 = CONS( X1, c3711 );
        CONSTANTEXP( ADR( c3711 ) );
        c3700 = CSTRING_TSCP( t4567 );
        CONSTANTEXP( ADR( c3700 ) );
        c3696 = STRINGTOSYMBOL( CSTRING_TSCP( "CHAR<=?" ) );
        CONSTANTEXP( ADR( c3696 ) );
        c3688 = STRINGTOSYMBOL( CSTRING_TSCP( "CHAR>?" ) );
        CONSTANTEXP( ADR( c3688 ) );
        c3676 = CSTRING_TSCP( t4568 );
        CONSTANTEXP( ADR( c3676 ) );
        c3675 = CSTRING_TSCP( t4569 );
        CONSTANTEXP( ADR( c3675 ) );
        c3674 = CSTRING_TSCP( t4570 );
        CONSTANTEXP( ADR( c3674 ) );
        c3654 = CSTRING_TSCP( t4571 );
        CONSTANTEXP( ADR( c3654 ) );
        c3596 = CSTRING_TSCP( t4572 );
        CONSTANTEXP( ADR( c3596 ) );
        c3595 = EMPTYLIST;
        X1 = EMPTYLIST;
        t4573 = CSTRING_TSCP( t4574 );
        X1 = CONS( t4573, X1 );
        t4575 = STRINGTOSYMBOL( CSTRING_TSCP( "UNQUOTE-SPLICING" ) );
        X1 = CONS( t4575, X1 );
        c3595 = CONS( X1, c3595 );
        X1 = EMPTYLIST;
        t4576 = CSTRING_TSCP( t4577 );
        X1 = CONS( t4576, X1 );
        t4578 = STRINGTOSYMBOL( CSTRING_TSCP( "UNQUOTE" ) );
        X1 = CONS( t4578, X1 );
        c3595 = CONS( X1, c3595 );
        X1 = EMPTYLIST;
        t4579 = CSTRING_TSCP( t4580 );
        X1 = CONS( t4579, X1 );
        t4581 = STRINGTOSYMBOL( CSTRING_TSCP( "QUASIQUOTE" ) );
        X1 = CONS( t4581, X1 );
        c3595 = CONS( X1, c3595 );
        X1 = EMPTYLIST;
        t4582 = CSTRING_TSCP( t4583 );
        X1 = CONS( t4582, X1 );
        t4584 = STRINGTOSYMBOL( CSTRING_TSCP( "QUOTE" ) );
        X1 = CONS( t4584, X1 );
        c3595 = CONS( X1, c3595 );
        CONSTANTEXP( ADR( c3595 ) );
        c3561 = CSTRING_TSCP( t4585 );
        CONSTANTEXP( ADR( c3561 ) );
        c3456 = CSTRING_TSCP( t4586 );
        CONSTANTEXP( ADR( c3456 ) );
        c3424 = EMPTYLIST;
        t4587 = STRINGTOSYMBOL( CSTRING_TSCP( "-" ) );
        c3424 = CONS( t4587, c3424 );
        t4588 = STRINGTOSYMBOL( CSTRING_TSCP( "+" ) );
        c3424 = CONS( t4588, c3424 );
        CONSTANTEXP( ADR( c3424 ) );
        c3423 = CSTRING_TSCP( t4589 );
        CONSTANTEXP( ADR( c3423 ) );
        c3422 = STRINGTOSYMBOL( CSTRING_TSCP( "SYMBOL->STRING" ) );
        CONSTANTEXP( ADR( c3422 ) );
        c3397 = CSTRING_TSCP( t4590 );
        CONSTANTEXP( ADR( c3397 ) );
        c3394 = CSTRING_TSCP( t4591 );
        CONSTANTEXP( ADR( c3394 ) );
        c3393 = CSTRING_TSCP( t4592 );
        CONSTANTEXP( ADR( c3393 ) );
        c3392 = CSTRING_TSCP( t4593 );
        CONSTANTEXP( ADR( c3392 ) );
        c3391 = CSTRING_TSCP( t4594 );
        CONSTANTEXP( ADR( c3391 ) );
        c3390 = CSTRING_TSCP( t4595 );
        CONSTANTEXP( ADR( c3390 ) );
        c3389 = CSTRING_TSCP( t4596 );
        CONSTANTEXP( ADR( c3389 ) );
        c3388 = STRINGTOSYMBOL( CSTRING_TSCP( "%TO-WRITE" ) );
        CONSTANTEXP( ADR( c3388 ) );
        c3387 = STRINGTOSYMBOL( CSTRING_TSCP( "%TO-DISPLAY" ) );
        CONSTANTEXP( ADR( c3387 ) );
        c3359 = CSTRING_TSCP( t4597 );
        CONSTANTEXP( ADR( c3359 ) );
        c3258 = CSTRING_TSCP( t4598 );
        CONSTANTEXP( ADR( c3258 ) );
        c3257 = STRINGTOSYMBOL( CSTRING_TSCP( "STRING-LENGTH" ) );
        CONSTANTEXP( ADR( c3257 ) );
        c3219 = STRINGTOSYMBOL( CSTRING_TSCP( "WRITE-CIRCLE" ) );
        CONSTANTEXP( ADR( c3219 ) );
        c3218 = STRINGTOSYMBOL( CSTRING_TSCP( "WRITE-LEVEL" ) );
        CONSTANTEXP( ADR( c3218 ) );
        c3217 = STRINGTOSYMBOL( CSTRING_TSCP( "WRITE-PRETTY" ) );
        CONSTANTEXP( ADR( c3217 ) );
        c3213 = STRINGTOSYMBOL( CSTRING_TSCP( "WRITE-WIDTH" ) );
        CONSTANTEXP( ADR( c3213 ) );
        c3212 = STRINGTOSYMBOL( CSTRING_TSCP( "WRITE-LENGTH" ) );
        CONSTANTEXP( ADR( c3212 ) );
        c3211 = STRINGTOSYMBOL( CSTRING_TSCP( "WRITE-TOKEN" ) );
        CONSTANTEXP( ADR( c3211 ) );
        c3192 = CSTRING_TSCP( t4599 );
        CONSTANTEXP( ADR( c3192 ) );
        c3168 = STRINGTOSYMBOL( CSTRING_TSCP( "PORT" ) );
        CONSTANTEXP( ADR( c3168 ) );
        c3167 = CSTRING_TSCP( t4600 );
        CONSTANTEXP( ADR( c3167 ) );
        c3113 = STRINGTOSYMBOL( CSTRING_TSCP( "READ-CHAR" ) );
        CONSTANTEXP( ADR( c3113 ) );
        c3112 = STRINGTOSYMBOL( CSTRING_TSCP( "PEEK-CHAR" ) );
        CONSTANTEXP( ADR( c3112 ) );
        c3105 = EMPTYLIST;
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 60 ), X1 );
        X1 = CONS( _TSCP( 17938 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 56 ), X1 );
        X1 = CONS( _TSCP( 17682 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 52 ), X1 );
        X1 = CONS( _TSCP( 17426 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 48 ), X1 );
        X1 = CONS( _TSCP( 17170 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 44 ), X1 );
        X1 = CONS( _TSCP( 16914 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 40 ), X1 );
        X1 = CONS( _TSCP( 16658 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 60 ), X1 );
        X1 = CONS( _TSCP( 26130 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 56 ), X1 );
        X1 = CONS( _TSCP( 25874 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 52 ), X1 );
        X1 = CONS( _TSCP( 25618 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 48 ), X1 );
        X1 = CONS( _TSCP( 25362 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 44 ), X1 );
        X1 = CONS( _TSCP( 25106 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 40 ), X1 );
        X1 = CONS( _TSCP( 24850 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 36 ), X1 );
        X1 = CONS( _TSCP( 14610 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 32 ), X1 );
        X1 = CONS( _TSCP( 14354 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 28 ), X1 );
        X1 = CONS( _TSCP( 14098 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 24 ), X1 );
        X1 = CONS( _TSCP( 13842 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 20 ), X1 );
        X1 = CONS( _TSCP( 13586 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 16 ), X1 );
        X1 = CONS( _TSCP( 13330 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 12 ), X1 );
        X1 = CONS( _TSCP( 13074 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 8 ), X1 );
        X1 = CONS( _TSCP( 12818 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 4 ), X1 );
        X1 = CONS( _TSCP( 12562 ), X1 );
        c3105 = CONS( X1, c3105 );
        X1 = EMPTYLIST;
        X1 = CONS( _TSCP( 0 ), X1 );
        X1 = CONS( _TSCP( 12306 ), X1 );
        c3105 = CONS( X1, c3105 );
        CONSTANTEXP( ADR( c3105 ) );
        c3104 = CSTRING_TSCP( t4601 );
        CONSTANTEXP( ADR( c3104 ) );
        c3103 = STRINGTOSYMBOL( CSTRING_TSCP( "FIXED->FLOAT" ) );
        CONSTANTEXP( ADR( c3103 ) );
        c2981 = CSTRING_TSCP( t4602 );
        CONSTANTEXP( ADR( c2981 ) );
        c2976 = CSTRING_TSCP( t4603 );
        CONSTANTEXP( ADR( c2976 ) );
        c2975 = STRINGTOSYMBOL( CSTRING_TSCP( "FLOAT->FIXED" ) );
        CONSTANTEXP( ADR( c2975 ) );
        c2946 = DOUBLE_TSCP( 0. );
        CONSTANTEXP( ADR( c2946 ) );
        c2936 = CSTRING_TSCP( t4604 );
        CONSTANTEXP( ADR( c2936 ) );
        c2933 = CSTRING_TSCP( t4605 );
        CONSTANTEXP( ADR( c2933 ) );
        c2929 = CSTRING_TSCP( t4606 );
        CONSTANTEXP( ADR( c2929 ) );
        c2833 = CSTRING_TSCP( t4607 );
        CONSTANTEXP( ADR( c2833 ) );
        c2832 = EMPTYLIST;
        c2832 = CONS( _TSCP( 30738 ), c2832 );
        c2832 = CONS( _TSCP( 22546 ), c2832 );
        CONSTANTEXP( ADR( c2832 ) );
        c2831 = EMPTYLIST;
        c2831 = CONS( _TSCP( 25618 ), c2831 );
        c2831 = CONS( _TSCP( 17426 ), c2831 );
        CONSTANTEXP( ADR( c2831 ) );
        c2830 = EMPTYLIST;
        c2830 = CONS( _TSCP( 28434 ), c2830 );
        c2830 = CONS( _TSCP( 20242 ), c2830 );
        CONSTANTEXP( ADR( c2830 ) );
        c2829 = EMPTYLIST;
        c2829 = CONS( _TSCP( 25106 ), c2829 );
        c2829 = CONS( _TSCP( 16914 ), c2829 );
        CONSTANTEXP( ADR( c2829 ) );
        c2766 = STRINGTOSYMBOL( CSTRING_TSCP( "VECTOR-REF" ) );
        CONSTANTEXP( ADR( c2766 ) );
        c2724 = EMPTYLIST;
        c2724 = CONS( _TSCP( 11538 ), c2724 );
        c2724 = CONS( _TSCP( 11026 ), c2724 );
        c2724 = CONS( _TSCP( 11794 ), c2724 );
        c2724 = CONS( _TSCP( 24082 ), c2724 );
        c2724 = CONS( _TSCP( 24338 ), c2724 );
        c2724 = CONS( _TSCP( 32274 ), c2724 );
        c2724 = CONS( _TSCP( 16146 ), c2724 );
        c2724 = CONS( _TSCP( 15890 ), c2724 );
        c2724 = CONS( _TSCP( 15634 ), c2724 );
        c2724 = CONS( _TSCP( 15378 ), c2724 );
        c2724 = CONS( _TSCP( 14866 ), c2724 );
        c2724 = CONS( _TSCP( 12050 ), c2724 );
        c2724 = CONS( _TSCP( 10770 ), c2724 );
        c2724 = CONS( _TSCP( 9746 ), c2724 );
        c2724 = CONS( _TSCP( 9490 ), c2724 );
        c2724 = CONS( _TSCP( 9234 ), c2724 );
        c2724 = CONS( _TSCP( 8466 ), c2724 );
        c2724 = CONS( _TSCP( 14610 ), c2724 );
        c2724 = CONS( _TSCP( 14354 ), c2724 );
        c2724 = CONS( _TSCP( 14098 ), c2724 );
        c2724 = CONS( _TSCP( 13842 ), c2724 );
        c2724 = CONS( _TSCP( 13586 ), c2724 );
        c2724 = CONS( _TSCP( 13330 ), c2724 );
        c2724 = CONS( _TSCP( 13074 ), c2724 );
        c2724 = CONS( _TSCP( 12818 ), c2724 );
        c2724 = CONS( _TSCP( 12562 ), c2724 );
        c2724 = CONS( _TSCP( 12306 ), c2724 );
        CONSTANTEXP( ADR( c2724 ) );
        c2610 = CSTRING_TSCP( t4608 );
        CONSTANTEXP( ADR( c2610 ) );
        c2606 = CSTRING_TSCP( t4609 );
        CONSTANTEXP( ADR( c2606 ) );
        c2603 = CSTRING_TSCP( t4610 );
        CONSTANTEXP( ADR( c2603 ) );
        c2602 = STRINGTOSYMBOL( CSTRING_TSCP( "VECTOR-SET!" ) );
        CONSTANTEXP( ADR( c2602 ) );
        c2456 = CSTRING_TSCP( t4611 );
        CONSTANTEXP( ADR( c2456 ) );
        c2455 = STRINGTOSYMBOL( CSTRING_TSCP( "INTEGER->CHAR" ) );
        CONSTANTEXP( ADR( c2455 ) );
        c2429 = CSTRING_TSCP( t4612 );
        CONSTANTEXP( ADR( c2429 ) );
        c2428 = STRINGTOSYMBOL( CSTRING_TSCP( "SPACE" ) );
        CONSTANTEXP( ADR( c2428 ) );
        c2424 = STRINGTOSYMBOL( CSTRING_TSCP( "RETURN" ) );
        CONSTANTEXP( ADR( c2424 ) );
        c2420 = STRINGTOSYMBOL( CSTRING_TSCP( "FORMFEED" ) );
        CONSTANTEXP( ADR( c2420 ) );
        c2416 = STRINGTOSYMBOL( CSTRING_TSCP( "LINEFEED" ) );
        CONSTANTEXP( ADR( c2416 ) );
        c2412 = STRINGTOSYMBOL( CSTRING_TSCP( "NEWLINE" ) );
        CONSTANTEXP( ADR( c2412 ) );
        c2408 = STRINGTOSYMBOL( CSTRING_TSCP( "TAB" ) );
        CONSTANTEXP( ADR( c2408 ) );
        c2354 = EMPTYLIST;
        c2354 = CONS( _TSCP( 15122 ), c2354 );
        c2354 = CONS( _TSCP( 8722 ), c2354 );
        c2354 = CONS( _TSCP( 10514 ), c2354 );
        c2354 = CONS( _TSCP( 10258 ), c2354 );
        CONSTANTEXP( ADR( c2354 ) );
        c2323 = CSTRING_TSCP( t4613 );
        CONSTANTEXP( ADR( c2323 ) );
        c2256 = EMPTYLIST;
        c2256 = CONS( _TSCP( 11794 ), c2256 );
        c2256 = CONS( _TSCP( 8978 ), c2256 );
        CONSTANTEXP( ADR( c2256 ) );
        c2228 = EMPTYLIST;
        c2228 = CONS( _TSCP( 24082 ), c2228 );
        c2228 = CONS( _TSCP( 24338 ), c2228 );
        c2228 = CONS( _TSCP( 32274 ), c2228 );
        c2228 = CONS( _TSCP( 16146 ), c2228 );
        c2228 = CONS( _TSCP( 15890 ), c2228 );
        c2228 = CONS( _TSCP( 15634 ), c2228 );
        c2228 = CONS( _TSCP( 15378 ), c2228 );
        c2228 = CONS( _TSCP( 14866 ), c2228 );
        c2228 = CONS( _TSCP( 12050 ), c2228 );
        c2228 = CONS( _TSCP( 10770 ), c2228 );
        c2228 = CONS( _TSCP( 9746 ), c2228 );
        c2228 = CONS( _TSCP( 9490 ), c2228 );
        c2228 = CONS( _TSCP( 9234 ), c2228 );
        c2228 = CONS( _TSCP( 8466 ), c2228 );
        CONSTANTEXP( ADR( c2228 ) );
        c2175 = CSTRING_TSCP( t4614 );
        CONSTANTEXP( ADR( c2175 ) );
        c2174 = STRINGTOSYMBOL( CSTRING_TSCP( "CHAR=?" ) );
        CONSTANTEXP( ADR( c2174 ) );
        c2156 = CSTRING_TSCP( t4615 );
        CONSTANTEXP( ADR( c2156 ) );
        c2155 = STRINGTOSYMBOL( CSTRING_TSCP( "READ" ) );
        CONSTANTEXP( ADR( c2155 ) );
        c2147 = STRINGTOSYMBOL( CSTRING_TSCP( "%RECORD" ) );
        CONSTANTEXP( ADR( c2147 ) );
        c2145 = STRINGTOSYMBOL( CSTRING_TSCP( "VECTOR" ) );
        CONSTANTEXP( ADR( c2145 ) );
        c2143 = STRINGTOSYMBOL( CSTRING_TSCP( "PERIOD" ) );
        CONSTANTEXP( ADR( c2143 ) );
        c2141 = STRINGTOSYMBOL( CSTRING_TSCP( "UNQUOTE" ) );
        CONSTANTEXP( ADR( c2141 ) );
        c2139 = STRINGTOSYMBOL( CSTRING_TSCP( "UNQUOTE-SPLICING" ) );
        CONSTANTEXP( ADR( c2139 ) );
        c2137 = STRINGTOSYMBOL( CSTRING_TSCP( "QUASIQUOTE" ) );
        CONSTANTEXP( ADR( c2137 ) );
        c2135 = STRINGTOSYMBOL( CSTRING_TSCP( "QUOTE" ) );
        CONSTANTEXP( ADR( c2135 ) );
        c2133 = STRINGTOSYMBOL( CSTRING_TSCP( "RIGHT-PAREN" ) );
        CONSTANTEXP( ADR( c2133 ) );
        c2131 = STRINGTOSYMBOL( CSTRING_TSCP( "LEFT-PAREN" ) );
        CONSTANTEXP( ADR( c2131 ) );
}

DEFTSCP( scrt7_token_2dleft_2dparen_v );
DEFCSTRING( t4616, "SCRT7_TOKEN-LEFT-PAREN" );
EXTERNTSCPP( sc_cons, XAL2( TSCP, TSCP ) );
EXTERNTSCP( sc_cons_v );
DEFTSCP( scrt7_token_2dright_2dparen_v );
DEFCSTRING( t4617, "SCRT7_TOKEN-RIGHT-PAREN" );
DEFTSCP( scrt7_token_2dquote_v );
DEFCSTRING( t4618, "SCRT7_TOKEN-QUOTE" );
DEFTSCP( scrt7_token_2dquasiquote_v );
DEFCSTRING( t4619, "SCRT7_TOKEN-QUASIQUOTE" );
DEFTSCP( scrt7_2dsplicing_542533dd_v );
DEFCSTRING( t4620, "SCRT7_TOKEN-UNQUOTE-SPLICING" );
DEFTSCP( scrt7_token_2dunquote_v );
DEFCSTRING( t4621, "SCRT7_TOKEN-UNQUOTE" );
DEFTSCP( scrt7_token_2dperiod_v );
DEFCSTRING( t4622, "SCRT7_TOKEN-PERIOD" );
DEFTSCP( scrt7_token_2dvector_v );
DEFCSTRING( t4623, "SCRT7_TOKEN-VECTOR" );
DEFTSCP( scrt7_token_2drecord_v );
DEFCSTRING( t4624, "SCRT7_TOKEN-RECORD" );
DEFTSCP( scrt7_peek_2dchar_2dport_v );
DEFCSTRING( t4625, "SCRT7_PEEK-CHAR-PORT" );
DEFTSCP( scrt7_read_2dchar_2dport_v );
DEFCSTRING( t4626, "SCRT7_READ-CHAR-PORT" );
DEFTSCP( scrt7_ort_2dproc_ae18f815_v );
DEFCSTRING( t4627, "SCRT7_READ-DATUM-PORT-PROC" );
DEFTSCP( scrt7_next_2dchar_v );
DEFCSTRING( t4628, "SCRT7_NEXT-CHAR" );
EXTERNTSCPP( scrt6_eof_2dobject_3f, XAL1( TSCP ) );
EXTERNTSCP( scrt6_eof_2dobject_3f_v );
EXTERNTSCPP( scdebug_error, XAL3( TSCP, TSCP, TSCP ) );
EXTERNTSCP( scdebug_error_v );

TSCP  scrt7_next_2dchar(  )
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( t4628 );
        X2 = scrt7_read_2dchar_2dport_v;
        X2 = UNKNOWNCALL( X2, 0 );
        X1 = VIA( PROCEDURE_CODE( X2 ) )( PROCEDURE_CLOSURE( X2 ) );
        if  ( FALSE( scrt6_eof_2dobject_3f( X1 ) ) )  goto L4631;
        POPSTACKTRACE( scdebug_error( c2155, c2156, EMPTYLIST ) );
L4631:
        POPSTACKTRACE( X1 );
}

DEFTSCP( scrt7_token_v );
DEFCSTRING( t4633, "SCRT7_TOKEN" );
EXTERNTSCPP( scrt7_comment_3f, XAL1( TSCP ) );
EXTERNTSCP( scrt7_comment_3f_v );
EXTERNTSCPP( scrt3_char_2dalphabetic_3f, XAL1( TSCP ) );
EXTERNTSCP( scrt3_char_2dalphabetic_3f_v );
EXTERNTSCPP( scrt7_identifier, XAL1( TSCP ) );
EXTERNTSCP( scrt7_identifier_v );
EXTERNTSCPP( scrt3_char_2dupcase, XAL1( TSCP ) );
EXTERNTSCP( scrt3_char_2dupcase_v );
EXTERNTSCPP( scrt7_read_2dstring, XAL0(  ) );
EXTERNTSCP( scrt7_read_2dstring_v );
EXTERNTSCPP( scrt3_char_2dnumeric_3f, XAL1( TSCP ) );
EXTERNTSCP( scrt3_char_2dnumeric_3f_v );
EXTERNTSCPP( scrt7_number, XAL3( TSCP, TSCP, TSCP ) );
EXTERNTSCP( scrt7_number_v );
EXTERNTSCPP( scrt7_character, XAL0(  ) );
EXTERNTSCP( scrt7_character_v );
EXTERNTSCP( scrt4_fix_2dchar_c117a402_v );
EXTERNTSCPP( scrt1_memq, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt1_memq_v );

TSCP  scrt7_token(  )
{
        TSCP  X22, 
              X21, 
              X20, 
              X19, 
              X18, 
              X17, 
              X16, 
              X15, 
              X14, 
              X13, 
              X12, 
              X11, 
              X10, 
              X9, 
              X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t4633 );
L4634:
        X1 = scrt7_next_2dchar(  );
        X1 = CONS( X1, EMPTYLIST );
        X2 = BOOLEAN( OR( EQ( PAIR_CAR( X1 ), 
                              C_CHAR( 040 ) ), 
                          AND( GTE( PAIR_CAR( X1 ), 
                                    C_CHAR( 011 ) ), 
                               LTE( PAIR_CAR( X1 ), 
                                    C_CHAR( 015 ) ) ) ) );
        if  ( TRUE( X2 ) )  GOBACK( L4634 );
        if  ( TRUE( scrt7_comment_3f( PAIR_CAR( X1 ) ) ) )  GOBACK( L4634 );
        if  ( FALSE( scrt3_char_2dalphabetic_3f( PAIR_CAR( X1 ) ) )
            )  goto L4643;
        X3 = scrt3_char_2dupcase( PAIR_CAR( X1 ) );
        POPSTACKTRACE( scrt7_identifier( X3 ) );
L4643:
        X3 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X3 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 8722 ) ), 
                       CHARACTERTAG ) ) )  goto L4646;
        X4 = CONS( _TSCP( 8722 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X3, X4 ) );
L4646:
        if  ( NEQ( _S2CINT( X3 ), _S2CINT( _TSCP( 8722 ) ) ) )  goto L4648;
        POPSTACKTRACE( scrt7_read_2dstring(  ) );
L4648:
        X4 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X4 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 10258 ) ), 
                       CHARACTERTAG ) ) )  goto L4651;
        X5 = CONS( _TSCP( 10258 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X4, X5 ) );
L4651:
        if  ( EQ( _S2CINT( X4 ), _S2CINT( _TSCP( 10258 ) ) ) )  goto L4653;
        X5 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X5 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 10514 ) ), 
                       CHARACTERTAG ) ) )  goto L4656;
        X6 = CONS( _TSCP( 10514 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X5, X6 ) );
L4656:
        if  ( EQ( _S2CINT( X5 ), _S2CINT( _TSCP( 10514 ) ) ) )  goto L4658;
        X6 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X6 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 10002 ) ), 
                       CHARACTERTAG ) ) )  goto L4661;
        X7 = CONS( _TSCP( 10002 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X6, X7 ) );
L4661:
        if  ( EQ( _S2CINT( X6 ), _S2CINT( _TSCP( 10002 ) ) ) )  goto L4663;
        X7 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X7 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 24594 ) ), 
                       CHARACTERTAG ) ) )  goto L4666;
        X8 = CONS( _TSCP( 24594 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X7, X8 ) );
L4666:
        if  ( EQ( _S2CINT( X7 ), _S2CINT( _TSCP( 24594 ) ) ) )  goto L4668;
        X8 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X8 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 11282 ) ), 
                       CHARACTERTAG ) ) )  goto L4671;
        X9 = CONS( _TSCP( 11282 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X8, X9 ) );
L4671:
        if  ( NEQ( _S2CINT( X8 ), 
                   _S2CINT( _TSCP( 11282 ) ) ) )  goto L4673;
        X10 = scrt7_peek_2dchar_2dport_v;
        X10 = UNKNOWNCALL( X10, 0 );
        X9 = VIA( PROCEDURE_CODE( X10 ) )( PROCEDURE_CLOSURE( X10 ) );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X9 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 16402 ) ), 
                       CHARACTERTAG ) ) )  goto L4676;
        X10 = CONS( _TSCP( 16402 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X9, X10 ) );
L4676:
        if  ( NEQ( _S2CINT( X9 ), 
                   _S2CINT( _TSCP( 16402 ) ) ) )  goto L4678;
        scrt7_next_2dchar(  );
        POPSTACKTRACE( scrt7_2dsplicing_542533dd_v );
L4678:
        POPSTACKTRACE( scrt7_token_2dunquote_v );
L4673:
        X9 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X9 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 11794 ) ), 
                       CHARACTERTAG ) ) )  goto L4682;
        X10 = CONS( _TSCP( 11794 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X9, X10 ) );
L4682:
        if  ( NEQ( _S2CINT( X9 ), 
                   _S2CINT( _TSCP( 11794 ) ) ) )  goto L4684;
        X11 = scrt7_peek_2dchar_2dport_v;
        X11 = UNKNOWNCALL( X11, 0 );
        X10 = VIA( PROCEDURE_CODE( X11 ) )( PROCEDURE_CLOSURE( X11 ) );
        if  ( FALSE( scrt3_char_2dnumeric_3f( X10 ) ) )  goto L4686;
        POPSTACKTRACE( scrt7_number( PAIR_CAR( X1 ), 
                                     _TSCP( 40 ), _TSCP( 4 ) ) );
L4686:
        X11 = scrt7_peek_2dchar_2dport_v;
        X11 = UNKNOWNCALL( X11, 0 );
        X10 = VIA( PROCEDURE_CODE( X11 ) )( PROCEDURE_CLOSURE( X11 ) );
        if  ( OR( EQ( X10, C_CHAR( 040 ) ), 
                  AND( GTE( X10, C_CHAR( 011 ) ), 
                       LTE( X10, C_CHAR( 015 ) ) ) ) )  goto L4688;
        POPSTACKTRACE( scrt7_identifier( PAIR_CAR( X1 ) ) );
L4688:
        POPSTACKTRACE( scrt7_token_2dperiod_v );
L4684:
        X10 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X10 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 8978 ) ), 
                       CHARACTERTAG ) ) )  goto L4691;
        X11 = CONS( _TSCP( 8978 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X10, X11 ) );
L4691:
        if  ( NEQ( _S2CINT( X10 ), 
                   _S2CINT( _TSCP( 8978 ) ) ) )  goto L4693;
        X12 = scrt7_next_2dchar(  );
        X11 = scrt3_char_2dupcase( X12 );
        SETGEN( PAIR_CAR( X1 ), X11 );
        X11 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X11 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 10258 ) ), 
                       CHARACTERTAG ) ) )  goto L4697;
        X12 = CONS( _TSCP( 10258 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X11, X12 ) );
L4697:
        if  ( EQ( _S2CINT( X11 ), 
                  _S2CINT( _TSCP( 10258 ) ) ) )  goto L4699;
        X12 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X12 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 23570 ) ), 
                       CHARACTERTAG ) ) )  goto L4702;
        X13 = CONS( _TSCP( 23570 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X12, X13 ) );
L4702:
        if  ( NEQ( _S2CINT( X12 ), 
                   _S2CINT( _TSCP( 23570 ) ) ) )  goto L4704;
        POPSTACKTRACE( scrt7_character(  ) );
L4704:
        X13 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X13 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 21522 ) ), 
                       CHARACTERTAG ) ) )  goto L4707;
        X14 = CONS( _TSCP( 21522 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X13, X14 ) );
L4707:
        if  ( EQ( _S2CINT( X13 ), 
                  _S2CINT( _TSCP( 21522 ) ) ) )  goto L4709;
        X14 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X14 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 17938 ) ), 
                       CHARACTERTAG ) ) )  goto L4712;
        X15 = CONS( _TSCP( 17938 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X14, X15 ) );
L4712:
        if  ( EQ( _S2CINT( X14 ), 
                  _S2CINT( _TSCP( 17938 ) ) ) )  goto L4714;
        X15 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X15 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 16914 ) ), 
                       CHARACTERTAG ) ) )  goto L4717;
        X16 = CONS( _TSCP( 16914 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X15, X16 ) );
L4717:
        if  ( NEQ( _S2CINT( X15 ), 
                   _S2CINT( _TSCP( 16914 ) ) ) )  goto L4719;
        X16 = scrt7_next_2dchar(  );
        POPSTACKTRACE( scrt7_number( X16, _TSCP( 8 ), _TSCP( 4 ) ) );
L4719:
        X16 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X16 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 20242 ) ), 
                       CHARACTERTAG ) ) )  goto L4722;
        X17 = CONS( _TSCP( 20242 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X16, X17 ) );
L4722:
        if  ( NEQ( _S2CINT( X16 ), 
                   _S2CINT( _TSCP( 20242 ) ) ) )  goto L4724;
        X17 = scrt7_next_2dchar(  );
        POPSTACKTRACE( scrt7_number( X17, _TSCP( 32 ), _TSCP( 4 ) ) );
L4724:
        X17 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X17 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 17426 ) ), 
                       CHARACTERTAG ) ) )  goto L4727;
        X18 = CONS( _TSCP( 17426 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X17, X18 ) );
L4727:
        if  ( NEQ( _S2CINT( X17 ), 
                   _S2CINT( _TSCP( 17426 ) ) ) )  goto L4729;
        X18 = scrt7_next_2dchar(  );
        POPSTACKTRACE( scrt7_number( X18, _TSCP( 40 ), _TSCP( 4 ) ) );
L4729:
        X18 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X18 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 22546 ) ), 
                       CHARACTERTAG ) ) )  goto L4732;
        X19 = CONS( _TSCP( 22546 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X18, X19 ) );
L4732:
        if  ( NEQ( _S2CINT( X18 ), 
                   _S2CINT( _TSCP( 22546 ) ) ) )  goto L4734;
        X19 = scrt7_next_2dchar(  );
        POPSTACKTRACE( scrt7_number( X19, _TSCP( 64 ), _TSCP( 4 ) ) );
L4734:
        X19 = scrt4_fix_2dchar_c117a402_v;
        if  ( FALSE( X19 ) )  goto L4745;
        X20 = PAIR_CAR( X1 );
        X21 = scrt4_fix_2dchar_c117a402_v;
        if  ( AND( EQ( TSCPIMMEDIATETAG( X20 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( X21 ), CHARACTERTAG ) )
            )  goto L4741;
        X22 = CONS( X21, EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X20, X22 ) );
L4741:
        if  ( NEQ( _S2CINT( X20 ), _S2CINT( X21 ) ) )  goto L4745;
        POPSTACKTRACE( scrt7_token_2drecord_v );
L4714:
        POPSTACKTRACE( FALSEVALUE );
L4709:
        POPSTACKTRACE( TRUEVALUE );
L4699:
        POPSTACKTRACE( scrt7_token_2dvector_v );
L4693:
        if  ( FALSE( scrt1_memq( PAIR_CAR( X1 ), c2228 ) ) )  goto L4746;
        POPSTACKTRACE( scrt7_identifier( PAIR_CAR( X1 ) ) );
L4746:
        X11 = PAIR_CAR( X1 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X11 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 23570 ) ), 
                       CHARACTERTAG ) ) )  goto L4749;
        X12 = CONS( _TSCP( 23570 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X11, X12 ) );
L4749:
        if  ( NEQ( _S2CINT( X11 ), 
                   _S2CINT( _TSCP( 23570 ) ) ) )  goto L4751;
        X12 = scrt7_next_2dchar(  );
        POPSTACKTRACE( scrt7_identifier( X12 ) );
L4751:
        X12 = BOOLEAN( EQ( _S2CUINT( PAIR_CAR( X1 ) ), 
                           _S2CUINT( _TSCP( 11026 ) ) ) );
        if  ( TRUE( X12 ) )  goto L4757;
        if  ( EQ( _S2CUINT( PAIR_CAR( X1 ) ), 
                  _S2CUINT( _TSCP( 11538 ) ) ) )  goto L4757;
        POPSTACKTRACE( scrt7_number( PAIR_CAR( X1 ), 
                                     _TSCP( 0 ), _TSCP( 0 ) ) );
L4668:
        POPSTACKTRACE( scrt7_token_2dquasiquote_v );
L4663:
        POPSTACKTRACE( scrt7_token_2dquote_v );
L4658:
        POPSTACKTRACE( scrt7_token_2dright_2dparen_v );
L4653:
        POPSTACKTRACE( scrt7_token_2dleft_2dparen_v );
L4745:
        POPSTACKTRACE( scdebug_error( c2155, 
                                      c2323, 
                                      CONS( PAIR_CAR( X1 ), 
                                            EMPTYLIST ) ) );
L4757:
        X3 = scrt7_peek_2dchar_2dport_v;
        X3 = UNKNOWNCALL( X3, 0 );
        X2 = VIA( PROCEDURE_CODE( X3 ) )( PROCEDURE_CLOSURE( X3 ) );
        X3 = scrt3_char_2dnumeric_3f( X2 );
        if  ( TRUE( X3 ) )  goto L4765;
        if  ( TRUE( scrt1_memq( X2, c2256 ) ) )  goto L4765;
        POPSTACKTRACE( scrt7_identifier( PAIR_CAR( X1 ) ) );
L4765:
        POPSTACKTRACE( scrt7_number( PAIR_CAR( X1 ), 
                                     _TSCP( 0 ), _TSCP( 0 ) ) );
}

DEFTSCP( scrt7_delimiter_3f_v );
DEFCSTRING( t4768, "SCRT7_DELIMITER?" );

TSCP  scrt7_delimiter_3f( c2343 )
        TSCP  c2343;
{
        TSCP  X1;

        PUSHSTACKTRACE( t4768 );
        X1 = scrt6_eof_2dobject_3f( c2343 );
        if  ( TRUE( X1 ) )  goto L4771;
        if  ( OR( EQ( c2343, C_CHAR( 040 ) ), 
                  AND( GTE( c2343, C_CHAR( 011 ) ), 
                       LTE( c2343, C_CHAR( 015 ) ) ) ) )  goto L4773;
        POPSTACKTRACE( scrt1_memq( c2343, c2354 ) );
L4773:
        POPSTACKTRACE( TRUEVALUE );
L4771:
        POPSTACKTRACE( X1 );
}

DEFTSCP( scrt7_comment_3f_v );
DEFCSTRING( t4775, "SCRT7_COMMENT?" );

TSCP  scrt7_comment_3f( c2356 )
        TSCP  c2356;
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( t4775 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( c2356 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 15122 ) ), 
                       CHARACTERTAG ) ) )  goto L4778;
        X1 = CONS( _TSCP( 15122 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( c2356, X1 ) );
L4778:
        if  ( NEQ( _S2CINT( c2356 ), 
                   _S2CINT( _TSCP( 15122 ) ) ) )  goto L4780;
L4782:
        X1 = scrt7_next_2dchar(  );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X1 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 2578 ) ), 
                       CHARACTERTAG ) ) )  goto L4785;
        X2 = CONS( _TSCP( 2578 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X1, X2 ) );
L4785:
        if  ( NEQ( _S2CINT( X1 ), _S2CINT( _TSCP( 2578 ) ) ) )  GOBACK( L4782 );
        POPSTACKTRACE( TRUEVALUE );
L4780:
        POPSTACKTRACE( FALSEVALUE );
}

DEFTSCP( scrt7_read_2dstring_v );
DEFCSTRING( t4789, "SCRT7_READ-STRING" );
EXTERNTSCPP( scrt3_list_2d_3estring, XAL1( TSCP ) );
EXTERNTSCP( scrt3_list_2d_3estring_v );
EXTERNTSCPP( scrt1_reverse, XAL1( TSCP ) );
EXTERNTSCP( scrt1_reverse_v );

TSCP  scrt7_read_2dstring(  )
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t4789 );
        X1 = EMPTYLIST;
        X2 = scrt7_next_2dchar(  );
L4792:
        X2 = CONS( X2, EMPTYLIST );
        X3 = PAIR_CAR( X2 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X3 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 8722 ) ), 
                       CHARACTERTAG ) ) )  goto L4794;
        X4 = CONS( _TSCP( 8722 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X3, X4 ) );
L4794:
        if  ( NEQ( _S2CINT( X3 ), _S2CINT( _TSCP( 8722 ) ) ) )  goto L4796;
        X4 = scrt1_reverse( X1 );
        POPSTACKTRACE( scrt3_list_2d_3estring( X4 ) );
L4796:
        X4 = PAIR_CAR( X2 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( _TSCP( 23570 ) ), 
                       CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( X4 ), CHARACTERTAG ) )
            )  goto L4800;
        X5 = CONS( X4, EMPTYLIST );
        scdebug_error( c2174, 
                       c2175, CONS( _TSCP( 23570 ), X5 ) );
L4800:
        if  ( NEQ( _S2CINT( _TSCP( 23570 ) ), 
                   _S2CINT( X4 ) ) )  goto L4802;
        X5 = scrt7_next_2dchar(  );
        SETGEN( PAIR_CAR( X2 ), X5 );
L4802:
        X4 = sc_cons( PAIR_CAR( X2 ), X1 );
        X2 = scrt7_next_2dchar(  );
        X1 = X4;
        GOBACK( L4792 );
}

DEFTSCP( scrt7_character_v );
DEFCSTRING( t4804, "SCRT7_CHARACTER" );
EXTERNTSCPP( scrt2__3c_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2__3c_2dtwo_v );
EXTERNTSCPP( scrt2__3e_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2__3e_2dtwo_v );

TSCP  scrt7_character(  )
{
        TSCP  X4, X3, X2, X1;

        PUSHSTACKTRACE( t4804 );
        X1 = scrt7_next_2dchar(  );
        if  ( FALSE( scrt3_char_2dalphabetic_3f( X1 ) ) )  goto L4807;
        X3 = scrt7_peek_2dchar_2dport_v;
        X3 = UNKNOWNCALL( X3, 0 );
        X2 = VIA( PROCEDURE_CODE( X3 ) )( PROCEDURE_CLOSURE( X3 ) );
        if  ( TRUE( scrt7_delimiter_3f( X2 ) ) )  goto L4809;
        X3 = scrt3_char_2dupcase( X1 );
        X2 = scrt7_identifier( X3 );
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c2408 ) ) )  goto L4812;
        X3 = BOOLEAN( NEQ( TSCPTAG( _TSCP( 36 ) ), FIXNUMTAG ) );
        if  ( TRUE( X3 ) )  goto L4819;
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 36 ) ), 
                             _S2CINT( _TSCP( 0 ) ) ), 
                      3 ) )  goto L4820;
        X4 = BOOLEAN( LT( _S2CINT( _TSCP( 36 ) ), 
                          _S2CINT( _TSCP( 0 ) ) ) );
        goto L4821;
L4820:
        X4 = scrt2__3c_2dtwo( _TSCP( 36 ), _TSCP( 0 ) );
L4821:
        if  ( TRUE( X4 ) )  goto L4819;
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 36 ) ), 
                             _S2CINT( _TSCP( 1020 ) ) ), 
                      3 ) )  goto L4828;
        if  ( GT( _S2CINT( _TSCP( 36 ) ), 
                  _S2CINT( _TSCP( 1020 ) ) ) )  goto L4819;
        goto L4835;
L4828:
        if  ( FALSE( scrt2__3e_2dtwo( _TSCP( 36 ), _TSCP( 1020 ) ) )
            )  goto L4835;
L4819:
        scdebug_error( c2455, 
                       c2456, CONS( _TSCP( 36 ), EMPTYLIST ) );
L4835:
        POPSTACKTRACE( FIX_CHAR( _TSCP( 36 ) ) );
L4812:
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c2412 ) ) )  goto L4836;
        X3 = BOOLEAN( NEQ( TSCPTAG( _TSCP( 40 ) ), FIXNUMTAG ) );
        if  ( TRUE( X3 ) )  goto L4843;
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 40 ) ), 
                             _S2CINT( _TSCP( 0 ) ) ), 
                      3 ) )  goto L4844;
        X4 = BOOLEAN( LT( _S2CINT( _TSCP( 40 ) ), 
                          _S2CINT( _TSCP( 0 ) ) ) );
        goto L4845;
L4844:
        X4 = scrt2__3c_2dtwo( _TSCP( 40 ), _TSCP( 0 ) );
L4845:
        if  ( TRUE( X4 ) )  goto L4843;
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 40 ) ), 
                             _S2CINT( _TSCP( 1020 ) ) ), 
                      3 ) )  goto L4852;
        if  ( GT( _S2CINT( _TSCP( 40 ) ), 
                  _S2CINT( _TSCP( 1020 ) ) ) )  goto L4843;
        goto L4859;
L4852:
        if  ( FALSE( scrt2__3e_2dtwo( _TSCP( 40 ), _TSCP( 1020 ) ) )
            )  goto L4859;
L4843:
        scdebug_error( c2455, 
                       c2456, CONS( _TSCP( 40 ), EMPTYLIST ) );
L4859:
        POPSTACKTRACE( FIX_CHAR( _TSCP( 40 ) ) );
L4836:
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c2416 ) ) )  goto L4860;
        X3 = BOOLEAN( NEQ( TSCPTAG( _TSCP( 40 ) ), FIXNUMTAG ) );
        if  ( TRUE( X3 ) )  goto L4867;
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 40 ) ), 
                             _S2CINT( _TSCP( 0 ) ) ), 
                      3 ) )  goto L4868;
        X4 = BOOLEAN( LT( _S2CINT( _TSCP( 40 ) ), 
                          _S2CINT( _TSCP( 0 ) ) ) );
        goto L4869;
L4868:
        X4 = scrt2__3c_2dtwo( _TSCP( 40 ), _TSCP( 0 ) );
L4869:
        if  ( TRUE( X4 ) )  goto L4867;
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 40 ) ), 
                             _S2CINT( _TSCP( 1020 ) ) ), 
                      3 ) )  goto L4876;
        if  ( GT( _S2CINT( _TSCP( 40 ) ), 
                  _S2CINT( _TSCP( 1020 ) ) ) )  goto L4867;
        goto L4883;
L4876:
        if  ( FALSE( scrt2__3e_2dtwo( _TSCP( 40 ), _TSCP( 1020 ) ) )
            )  goto L4883;
L4867:
        scdebug_error( c2455, 
                       c2456, CONS( _TSCP( 40 ), EMPTYLIST ) );
L4883:
        POPSTACKTRACE( FIX_CHAR( _TSCP( 40 ) ) );
L4860:
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c2420 ) ) )  goto L4884;
        X3 = BOOLEAN( NEQ( TSCPTAG( _TSCP( 48 ) ), FIXNUMTAG ) );
        if  ( TRUE( X3 ) )  goto L4891;
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 48 ) ), 
                             _S2CINT( _TSCP( 0 ) ) ), 
                      3 ) )  goto L4892;
        X4 = BOOLEAN( LT( _S2CINT( _TSCP( 48 ) ), 
                          _S2CINT( _TSCP( 0 ) ) ) );
        goto L4893;
L4892:
        X4 = scrt2__3c_2dtwo( _TSCP( 48 ), _TSCP( 0 ) );
L4893:
        if  ( TRUE( X4 ) )  goto L4891;
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 48 ) ), 
                             _S2CINT( _TSCP( 1020 ) ) ), 
                      3 ) )  goto L4900;
        if  ( GT( _S2CINT( _TSCP( 48 ) ), 
                  _S2CINT( _TSCP( 1020 ) ) ) )  goto L4891;
        goto L4907;
L4900:
        if  ( FALSE( scrt2__3e_2dtwo( _TSCP( 48 ), _TSCP( 1020 ) ) )
            )  goto L4907;
L4891:
        scdebug_error( c2455, 
                       c2456, CONS( _TSCP( 48 ), EMPTYLIST ) );
L4907:
        POPSTACKTRACE( FIX_CHAR( _TSCP( 48 ) ) );
L4884:
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c2424 ) ) )  goto L4908;
        X3 = BOOLEAN( NEQ( TSCPTAG( _TSCP( 52 ) ), FIXNUMTAG ) );
        if  ( TRUE( X3 ) )  goto L4915;
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 52 ) ), 
                             _S2CINT( _TSCP( 0 ) ) ), 
                      3 ) )  goto L4916;
        X4 = BOOLEAN( LT( _S2CINT( _TSCP( 52 ) ), 
                          _S2CINT( _TSCP( 0 ) ) ) );
        goto L4917;
L4916:
        X4 = scrt2__3c_2dtwo( _TSCP( 52 ), _TSCP( 0 ) );
L4917:
        if  ( TRUE( X4 ) )  goto L4915;
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 52 ) ), 
                             _S2CINT( _TSCP( 1020 ) ) ), 
                      3 ) )  goto L4924;
        if  ( GT( _S2CINT( _TSCP( 52 ) ), 
                  _S2CINT( _TSCP( 1020 ) ) ) )  goto L4915;
        goto L4931;
L4924:
        if  ( FALSE( scrt2__3e_2dtwo( _TSCP( 52 ), _TSCP( 1020 ) ) )
            )  goto L4931;
L4915:
        scdebug_error( c2455, 
                       c2456, CONS( _TSCP( 52 ), EMPTYLIST ) );
L4931:
        POPSTACKTRACE( FIX_CHAR( _TSCP( 52 ) ) );
L4908:
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c2428 ) ) )  goto L4932;
        X3 = BOOLEAN( NEQ( TSCPTAG( _TSCP( 128 ) ), FIXNUMTAG ) );
        if  ( TRUE( X3 ) )  goto L4939;
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 128 ) ), 
                             _S2CINT( _TSCP( 0 ) ) ), 
                      3 ) )  goto L4940;
        X4 = BOOLEAN( LT( _S2CINT( _TSCP( 128 ) ), 
                          _S2CINT( _TSCP( 0 ) ) ) );
        goto L4941;
L4940:
        X4 = scrt2__3c_2dtwo( _TSCP( 128 ), _TSCP( 0 ) );
L4941:
        if  ( TRUE( X4 ) )  goto L4939;
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 128 ) ), 
                             _S2CINT( _TSCP( 1020 ) ) ), 
                      3 ) )  goto L4948;
        if  ( GT( _S2CINT( _TSCP( 128 ) ), 
                  _S2CINT( _TSCP( 1020 ) ) ) )  goto L4939;
        goto L4955;
L4948:
        if  ( FALSE( scrt2__3e_2dtwo( _TSCP( 128 ), _TSCP( 1020 ) ) )
            )  goto L4955;
L4939:
        scdebug_error( c2455, 
                       c2456, 
                       CONS( _TSCP( 128 ), EMPTYLIST ) );
L4955:
        POPSTACKTRACE( FIX_CHAR( _TSCP( 128 ) ) );
L4932:
        POPSTACKTRACE( scdebug_error( c2155, 
                                      c2429, 
                                      CONS( X2, EMPTYLIST ) ) );
L4809:
        POPSTACKTRACE( X1 );
L4807:
        POPSTACKTRACE( X1 );
}

DEFTSCP( scrt7_idtable_v );
DEFCSTRING( t4956, "SCRT7_IDTABLE" );
EXTERNTSCPP( sc_make_2dvector, XAL2( TSCP, TSCP ) );
EXTERNTSCP( sc_make_2dvector_v );
EXTERNTSCPP( scrt2__2b_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2__2b_2dtwo_v );
EXTERNTSCPP( scrt1__24__car_2derror, XAL1( TSCP ) );
EXTERNTSCP( scrt1__24__car_2derror_v );
DEFTSCP( scrt7_identifier_v );
DEFCSTRING( t5054, "SCRT7_IDENTIFIER" );
EXTERNTSCPP( sc_string_2d_3esymbol, XAL1( TSCP ) );
EXTERNTSCP( sc_string_2d_3esymbol_v );

TSCP  scrt7_identifier( f2740 )
        TSCP  f2740;
{
        TSCP  X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t5054 );
        X2 = sc_cons( f2740, EMPTYLIST );
        X1 = X2;
        X2 = X1;
L5059:
        X4 = scrt7_peek_2dchar_2dport_v;
        X4 = UNKNOWNCALL( X4, 0 );
        X3 = VIA( PROCEDURE_CODE( X4 ) )( PROCEDURE_CLOSURE( X4 ) );
        if  ( NEQ( TSCPIMMEDIATETAG( X3 ), CHARACTERTAG ) )  goto L5061;
        X5 = C_FIXED( CHAR_C( X3 ) );
        X6 = scrt7_idtable_v;
        if  ( AND( EQ( TSCPTAG( X6 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X6 ), VECTORTAG ) ) )  goto L5064;
        scdebug_error( c2766, 
                       c2603, CONS( X6, EMPTYLIST ) );
L5064:
        if  ( EQ( TSCPTAG( X5 ), FIXNUMTAG ) )  goto L5066;
        scdebug_error( c2766, 
                       c2606, CONS( X5, EMPTYLIST ) );
L5066:
        if  ( LT( _S2CUINT( FIXED_C( X5 ) ), 
                  _S2CUINT( VECTOR_LENGTH( X6 ) ) ) )  goto L5068;
        scdebug_error( c2766, 
                       c2610, CONS( X5, EMPTYLIST ) );
L5068:
        X4 = VECTOR_ELEMENT( X6, X5 );
        goto L5062;
L5061:
        X4 = FALSEVALUE;
L5062:
        if  ( NEQ( TSCPIMMEDIATETAG( X4 ), CHARACTERTAG ) )  goto L5071;
        X5 = scrt7_read_2dchar_2dport_v;
        X5 = UNKNOWNCALL( X5, 0 );
        VIA( PROCEDURE_CODE( X5 ) )( PROCEDURE_CLOSURE( X5 ) );
        X2 = sc_cons( X4, X2 );
        GOBACK( L5059 );
L5071:
        if  ( FALSE( X4 ) )  goto L5074;
        X5 = scrt7_read_2dchar_2dport_v;
        X5 = UNKNOWNCALL( X5, 0 );
        VIA( PROCEDURE_CODE( X5 ) )( PROCEDURE_CLOSURE( X5 ) );
        X5 = scrt7_next_2dchar(  );
        X2 = sc_cons( X5, X2 );
        GOBACK( L5059 );
L5074:
        X6 = scrt1_reverse( X2 );
        X5 = scrt3_list_2d_3estring( X6 );
        POPSTACKTRACE( sc_string_2d_3esymbol( X5 ) );
}

DEFTSCP( scrt7_maxintf_v );
DEFCSTRING( t5077, "SCRT7_MAXINTF" );
DEFTSCP( scrt7_minintf_v );
DEFCSTRING( t5078, "SCRT7_MININTF" );
DEFTSCP( scrt7_number_v );
DEFCSTRING( t5079, "SCRT7_NUMBER" );
EXTERNTSCPP( scrt2_zero_3f, XAL1( TSCP ) );
EXTERNTSCP( scrt2_zero_3f_v );
EXTERNTSCPP( scrt1_memv, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt1_memv_v );
EXTERNTSCPP( scrt7_accv, XAL3( TSCP, TSCP, TSCP ) );
EXTERNTSCP( scrt7_accv_v );
EXTERNTSCPP( scrt2__3e_3d_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2__3e_3d_2dtwo_v );
EXTERNTSCPP( scrt2__2a_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2__2a_2dtwo_v );
EXTERNTSCPP( scrt2_max_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2_max_2dtwo_v );
EXTERNTSCPP( scrt2__3d_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2__3d_2dtwo_v );
EXTERNTSCPP( sc_readnumber, XAL2( TSCP, TSCP ) );
EXTERNTSCP( sc_readnumber_v );
EXTERNTSCPP( scrt2__2d_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2__2d_2dtwo_v );

TSCP  scrt7_number( f2782, b2783, s2784 )
        TSCP  f2782, b2783, s2784;
{
        TSCP  X14, 
              X13, 
              X12, 
              X11, 
              X10, 
              X9, 
              X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t5079 );
        f2782 = CONS( f2782, EMPTYLIST );
        b2783 = CONS( b2783, EMPTYLIST );
        s2784 = CONS( s2784, EMPTYLIST );
        X4 = PAIR_CAR( s2784 );
        if  ( NEQ( TSCPTAG( X4 ), FIXNUMTAG ) )  goto L5083;
        if  ( EQ( _S2CUINT( X4 ), _S2CUINT( _TSCP( 0 ) ) ) )  goto L5087;
        goto L5101;
L5083:
        if  ( FALSE( scrt2_zero_3f( X4 ) ) )  goto L5101;
L5087:
        X5 = PAIR_CAR( f2782 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X5 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 11026 ) ), 
                       CHARACTERTAG ) ) )  goto L5092;
        X6 = CONS( _TSCP( 11026 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X5, X6 ) );
L5092:
        if  ( NEQ( _S2CINT( X5 ), 
                   _S2CINT( _TSCP( 11026 ) ) ) )  goto L5094;
        X6 = _TSCP( 4 );
        SETGEN( PAIR_CAR( s2784 ), X6 );
        X6 = scrt7_next_2dchar(  );
        SETGEN( PAIR_CAR( f2782 ), X6 );
        goto L5101;
L5094:
        X6 = PAIR_CAR( f2782 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X6 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 11538 ) ), 
                       CHARACTERTAG ) ) )  goto L5098;
        X7 = CONS( _TSCP( 11538 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X6, X7 ) );
L5098:
        if  ( NEQ( _S2CINT( X6 ), 
                   _S2CINT( _TSCP( 11538 ) ) ) )  goto L5100;
        X7 = _TSCP( -4 );
        SETGEN( PAIR_CAR( s2784 ), X7 );
        X7 = scrt7_next_2dchar(  );
        SETGEN( PAIR_CAR( f2782 ), X7 );
        goto L5101;
L5100:
        X7 = _TSCP( 4 );
        SETGEN( PAIR_CAR( s2784 ), X7 );
L5101:
        X4 = PAIR_CAR( b2783 );
        if  ( NEQ( TSCPTAG( X4 ), FIXNUMTAG ) )  goto L5105;
        if  ( EQ( _S2CUINT( X4 ), _S2CUINT( _TSCP( 0 ) ) ) )  goto L5109;
        goto L5117;
L5105:
        if  ( FALSE( scrt2_zero_3f( X4 ) ) )  goto L5117;
L5109:
        X5 = PAIR_CAR( f2782 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X5 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 8978 ) ), 
                       CHARACTERTAG ) ) )  goto L5114;
        X6 = CONS( _TSCP( 8978 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X5, X6 ) );
L5114:
        if  ( NEQ( _S2CINT( X5 ), _S2CINT( _TSCP( 8978 ) ) ) )  goto L5116;
        X6 = scrt7_next_2dchar(  );
        if  ( FALSE( scrt1_memv( X6, c2829 ) ) )  goto L5120;
        X7 = _TSCP( 8 );
        SETGEN( PAIR_CAR( b2783 ), X7 );
        goto L5127;
L5120:
        if  ( FALSE( scrt1_memv( X6, c2830 ) ) )  goto L5122;
        X7 = _TSCP( 32 );
        SETGEN( PAIR_CAR( b2783 ), X7 );
        goto L5127;
L5122:
        if  ( FALSE( scrt1_memv( X6, c2831 ) ) )  goto L5124;
        X7 = _TSCP( 40 );
        SETGEN( PAIR_CAR( b2783 ), X7 );
        goto L5127;
L5124:
        if  ( FALSE( scrt1_memv( X6, c2832 ) ) )  goto L5126;
        X7 = _TSCP( 64 );
        SETGEN( PAIR_CAR( b2783 ), X7 );
        goto L5127;
L5126:
        scdebug_error( c2155, 
                       c2833, CONS( X6, EMPTYLIST ) );
L5127:
        X6 = scrt7_next_2dchar(  );
        SETGEN( PAIR_CAR( f2782 ), X6 );
        goto L5117;
L5116:
        X6 = _TSCP( 40 );
        SETGEN( PAIR_CAR( b2783 ), X6 );
L5117:
        X4 = sc_cons( PAIR_CAR( f2782 ), EMPTYLIST );
        X1 = X4;
        X5 = scrt7_peek_2dchar_2dport_v;
        X5 = UNKNOWNCALL( X5, 0 );
        X4 = VIA( PROCEDURE_CODE( X5 ) )( PROCEDURE_CLOSURE( X5 ) );
        X6 = PAIR_CAR( f2782 );
        if  ( NEQ( _S2CUINT( X6 ), 
                   _S2CUINT( _TSCP( 12306 ) ) ) )  goto L5131;
        X5 = _TSCP( 0 );
        goto L5134;
L5131:
        if  ( NEQ( _S2CUINT( X6 ), 
                   _S2CUINT( _TSCP( 12562 ) ) ) )  goto L5133;
        X5 = _TSCP( 4 );
        goto L5134;
L5133:
        X5 = _TSCP( -4 );
L5134:
        X6 = scrt7_accv( _TSCP( 0 ), 
                         PAIR_CAR( b2783 ), 
                         PAIR_CAR( f2782 ) );
        X7 = C_FIXED( CHAR_C( PAIR_CAR( f2782 ) ) );
        X2 = BOOLEAN( EQ( _S2CUINT( PAIR_CAR( f2782 ) ), 
                          _S2CUINT( _TSCP( 11794 ) ) ) );
L5135:
        if  ( FALSE( scrt7_delimiter_3f( X4 ) ) )  goto L5136;
        if  ( BITAND( BITOR( _S2CINT( X6 ), 
                             _S2CINT( _TSCP( 0 ) ) ), 
                      3 ) )  goto L5138;
        X8 = BOOLEAN( GTE( _S2CINT( X6 ), 
                           _S2CINT( _TSCP( 0 ) ) ) );
        goto L5139;
L5138:
        X8 = scrt2__3e_3d_2dtwo( X6, _TSCP( 0 ) );
L5139:
        if  ( FALSE( X8 ) )  goto L5146;
        if  ( TRUE( X2 ) )  goto L5146;
        X9 = PAIR_CAR( s2784 );
        if  ( BITAND( BITOR( _S2CINT( X9 ), _S2CINT( X6 ) ), 
                      3 ) )  goto L5148;
        X3 = _TSCP( ITIMES( FIXED_C( X9 ), _S2CINT( X6 ) ) );
        goto L5149;
L5148:
        X3 = scrt2__2a_2dtwo( X9, X6 );
L5149:
        if  ( EQ( TSCPTAG( X3 ), FIXNUMTAG ) )  goto L5151;
        X9 = scrt7_maxintf_v;
        if  ( BITAND( BITOR( _S2CINT( X3 ), _S2CINT( X9 ) ), 
                      3 ) )  goto L5155;
        if  ( LTE( _S2CINT( X3 ), _S2CINT( X9 ) ) )  goto L5159;
        POPSTACKTRACE( X3 );
L5155:
        if  ( FALSE( scrt2__3e_2dtwo( X3, X9 ) ) )  goto L5159;
        POPSTACKTRACE( X3 );
L5151:
        POPSTACKTRACE( X3 );
L5136:
        scrt7_next_2dchar(  );
        X8 = sc_cons( X4, X1 );
        X10 = scrt7_peek_2dchar_2dport_v;
        X10 = UNKNOWNCALL( X10, 0 );
        X9 = VIA( PROCEDURE_CODE( X10 ) )( PROCEDURE_CLOSURE( X10 ) );
        if  ( NEQ( _S2CUINT( X4 ), 
                   _S2CUINT( _TSCP( 12306 ) ) ) )  goto L5163;
        if  ( BITAND( BITOR( _S2CINT( X5 ), 
                             _S2CINT( _TSCP( 8 ) ) ), 
                      3 ) )  goto L5165;
        X10 = _TSCP( ITIMES( FIXED_C( X5 ), 
                             _S2CINT( _TSCP( 8 ) ) ) );
        goto L5168;
L5165:
        X10 = scrt2__2a_2dtwo( X5, _TSCP( 8 ) );
        goto L5168;
L5163:
        if  ( NEQ( _S2CUINT( X4 ), 
                   _S2CUINT( _TSCP( 12562 ) ) ) )  goto L5167;
        if  ( BITAND( BITOR( _S2CINT( X5 ), 
                             _S2CINT( _TSCP( 8 ) ) ), 
                      3 ) )  goto L5169;
        X11 = _TSCP( ITIMES( FIXED_C( X5 ), 
                             _S2CINT( _TSCP( 8 ) ) ) );
        goto L5170;
L5169:
        X11 = scrt2__2a_2dtwo( X5, _TSCP( 8 ) );
L5170:
        if  ( BITAND( BITOR( _S2CINT( X11 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L5172;
        X10 = _TSCP( IPLUS( _S2CINT( X11 ), 
                            _S2CINT( _TSCP( 4 ) ) ) );
        goto L5168;
L5172:
        X10 = scrt2__2b_2dtwo( X11, _TSCP( 4 ) );
        goto L5168;
L5167:
        X10 = _TSCP( -4 );
L5168:
        X11 = scrt7_accv( X6, PAIR_CAR( b2783 ), X4 );
        X13 = C_FIXED( CHAR_C( X4 ) );
        if  ( BITAND( BITOR( _S2CINT( X7 ), _S2CINT( X13 ) ), 
                      3 ) )  goto L5175;
        if  ( LTE( _S2CINT( X7 ), _S2CINT( X13 ) ) )  goto L5177;
        X12 = X7;
        goto L5176;
L5177:
        X12 = X13;
        goto L5176;
L5175:
        X12 = scrt2_max_2dtwo( X7, X13 );
L5176:
        if  ( TRUE( X2 ) )  goto L5190;
        if  ( NEQ( _S2CUINT( X4 ), 
                   _S2CUINT( _TSCP( 11794 ) ) ) )  goto L5181;
        X2 = TRUEVALUE;
        goto L5190;
L5181:
        X14 = PAIR_CAR( b2783 );
        if  ( BITAND( BITOR( _S2CINT( X14 ), 
                             _S2CINT( _TSCP( 64 ) ) ), 
                      3 ) )  goto L5184;
        X13 = BOOLEAN( NEQ( _S2CUINT( X14 ), 
                            _S2CUINT( _TSCP( 64 ) ) ) );
        goto L5187;
L5184:
        if  ( FALSE( scrt2__3d_2dtwo( X14, _TSCP( 64 ) ) ) )  goto L5186;
        X13 = FALSEVALUE;
        goto L5187;
L5186:
        X13 = TRUEVALUE;
L5187:
        if  ( FALSE( X13 ) )  goto L5189;
        if  ( NEQ( _S2CUINT( X4 ), 
                   _S2CUINT( _TSCP( 25874 ) ) ) )  goto L5191;
        X2 = TRUEVALUE;
        goto L5190;
L5191:
        X2 = BOOLEAN( EQ( _S2CUINT( X4 ), 
                          _S2CUINT( _TSCP( 17682 ) ) ) );
        goto L5190;
L5189:
        X2 = X13;
L5190:
        X7 = X12;
        X6 = X11;
        X5 = X10;
        X4 = X9;
        X1 = X8;
        GOBACK( L5135 );
L5146:
        X5 = scrt1_reverse( X1 );
        X4 = scrt3_list_2d_3estring( X5 );
        if  ( TRUE( X2 ) )  goto L5194;
        scdebug_error( c2155, 
                       c2929, CONS( X4, EMPTYLIST ) );
L5194:
        if  ( EQ( _S2CUINT( PAIR_CAR( b2783 ) ), 
                  _S2CUINT( _TSCP( 40 ) ) ) )  goto L5196;
        scdebug_error( c2155, 
                       c2933, CONS( X4, EMPTYLIST ) );
L5196:
        X5 = sc_readnumber( X4, _TSCP( 0 ) );
        if  ( FALSE( X5 ) )  goto L5199;
        if  ( NEQ( _S2CUINT( PAIR_CAR( s2784 ) ), 
                   _S2CUINT( _TSCP( -4 ) ) ) )  goto L5201;
        if  ( NEQ( TSCPTAG( X5 ), FIXNUMTAG ) )  goto L5203;
        POPSTACKTRACE( _TSCP( INEGATE( _S2CINT( X5 ) ) ) );
L5203:
        POPSTACKTRACE( scrt2__2d_2dtwo( c2946, X5 ) );
L5201:
        POPSTACKTRACE( X5 );
L5199:
        POPSTACKTRACE( scdebug_error( c2155, 
                                      c2936, 
                                      CONS( X4, EMPTYLIST ) ) );
L5159:
        X4 = scrt7_minintf_v;
        if  ( BITAND( BITOR( _S2CINT( X3 ), _S2CINT( X4 ) ), 
                      3 ) )  goto L5207;
        if  ( GTE( _S2CINT( X3 ), _S2CINT( X4 ) ) )  goto L5211;
        POPSTACKTRACE( X3 );
L5207:
        if  ( FALSE( scrt2__3c_2dtwo( X3, X4 ) ) )  goto L5211;
        POPSTACKTRACE( X3 );
L5211:
        if  ( AND( EQ( TSCPTAG( X3 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X3 ), DOUBLEFLOATTAG ) )
            )  goto L5215;
        scdebug_error( c2975, 
                       c2976, CONS( X3, EMPTYLIST ) );
L5215:
        X4 = BOOLEAN( LT( FLOAT_VALUE( X3 ), MINTSCPINTF ) );
        if  ( TRUE( X4 ) )  goto L5221;
        if  ( LTE( FLOAT_VALUE( X3 ), MAXTSCPINTF ) )  goto L5224;
L5221:
        scdebug_error( c2975, 
                       c2981, CONS( X3, EMPTYLIST ) );
L5224:
        POPSTACKTRACE( FLT_FIX( X3 ) );
}

DEFTSCP( scrt7_max_2daccv_2dvalue_v );
DEFCSTRING( t5225, "SCRT7_MAX-ACCV-VALUE" );
EXTERNTSCPP( scrt2_quotient, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2_quotient_v );
DEFTSCP( scrt7_accv_v );
DEFCSTRING( t5249, "SCRT7_ACCV" );
EXTERNTSCPP( scrt1_assq, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt1_assq_v );
EXTERNTSCPP( scrt1__24__cdr_2derror, XAL1( TSCP ) );
EXTERNTSCP( scrt1__24__cdr_2derror_v );

TSCP  scrt7_accv( v3033, b3034, c3035 )
        TSCP  v3033, b3034, c3035;
{
        TSCP  X4, X3, X2, X1;

        PUSHSTACKTRACE( t5249 );
L5250:
        X1 = scrt1_assq( c3035, c3105 );
        if  ( EQ( _S2CUINT( v3033 ), 
                  _S2CUINT( _TSCP( -4 ) ) ) )  goto L5252;
        if  ( FALSE( X1 ) )  goto L5254;
        if  ( EQ( TSCPTAG( X1 ), PAIRTAG ) )  goto L5257;
        scrt1__24__cdr_2derror( X1 );
L5257:
        X3 = PAIR_CDR( X1 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L5260;
        scrt1__24__car_2derror( X3 );
L5260:
        X2 = PAIR_CAR( X3 );
        if  ( BITAND( BITOR( _S2CINT( X2 ), 
                             _S2CINT( b3034 ) ), 
                      3 ) )  goto L5264;
        if  ( LT( _S2CINT( X2 ), _S2CINT( b3034 ) ) )  goto L5268;
        POPSTACKTRACE( _TSCP( -4 ) );
L5264:
        if  ( FALSE( scrt2__3e_3d_2dtwo( X2, b3034 ) ) )  goto L5268;
        POPSTACKTRACE( _TSCP( -4 ) );
L5254:
        POPSTACKTRACE( _TSCP( -4 ) );
L5252:
        POPSTACKTRACE( _TSCP( -4 ) );
L5268:
        X2 = BOOLEAN( EQ( TSCPTAG( v3033 ), FIXNUMTAG ) );
        if  ( FALSE( X2 ) )  goto L5285;
        X3 = scrt7_max_2daccv_2dvalue_v;
        if  ( BITAND( BITOR( _S2CINT( v3033 ), 
                             _S2CINT( X3 ) ), 
                      3 ) )  goto L5277;
        if  ( GT( _S2CINT( v3033 ), _S2CINT( X3 ) ) )  goto L5281;
        goto L5285;
L5277:
        if  ( FALSE( scrt2__3e_2dtwo( v3033, X3 ) ) )  goto L5285;
L5281:
        if  ( EQ( TSCPTAG( v3033 ), FIXNUMTAG ) )  goto L5287;
        scdebug_error( c3103, 
                       c3104, CONS( v3033, EMPTYLIST ) );
L5287:
        X2 = FIX_FLT( v3033 );
        v3033 = X2;
        GOBACK( L5250 );
L5285:
        if  ( BITAND( BITOR( _S2CINT( b3034 ), 
                             _S2CINT( v3033 ) ), 
                      3 ) )  goto L5289;
        X2 = _TSCP( ITIMES( FIXED_C( b3034 ), 
                            _S2CINT( v3033 ) ) );
        goto L5290;
L5289:
        X2 = scrt2__2a_2dtwo( b3034, v3033 );
L5290:
        X4 = PAIR_CDR( X1 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto L5293;
        scrt1__24__car_2derror( X4 );
L5293:
        X3 = PAIR_CAR( X4 );
        if  ( BITAND( BITOR( _S2CINT( X2 ), _S2CINT( X3 ) ), 
                      3 ) )  goto L5296;
        POPSTACKTRACE( _TSCP( IPLUS( _S2CINT( X2 ), 
                                     _S2CINT( X3 ) ) ) );
L5296:
        POPSTACKTRACE( scrt2__2b_2dtwo( X2, X3 ) );
}

DEFTSCP( scrt7_read_2ddatum_v );
DEFCSTRING( t5298, "SCRT7_READ-DATUM" );
EXTERNTSCPP( scrt7_datum, XAL1( TSCP ) );
EXTERNTSCP( scrt7_datum_v );

TSCP  scrt7_read_2ddatum( p3107 )
        TSCP  p3107;
{
        TSCP  X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t5298 );
        X1 = scrt7_ort_2dproc_ae18f815_v;
        X2 = scrt7_read_2dchar_2dport_v;
        X3 = scrt7_peek_2dchar_2dport_v;
        X4 = p3107;
        X4 = UNKNOWNCALL( X4, 1 );
        scrt7_peek_2dchar_2dport_v = VIA( PROCEDURE_CODE( X4 ) )( c3112, 
                                                                  PROCEDURE_CLOSURE( X4 ) );
        X4 = p3107;
        X4 = UNKNOWNCALL( X4, 1 );
        scrt7_read_2dchar_2dport_v = VIA( PROCEDURE_CODE( X4 ) )( c3113, 
                                                                  PROCEDURE_CLOSURE( X4 ) );
        scrt7_ort_2dproc_ae18f815_v = p3107;
        X6 = scrt7_peek_2dchar_2dport_v;
        X6 = UNKNOWNCALL( X6, 0 );
        X5 = VIA( PROCEDURE_CODE( X6 ) )( PROCEDURE_CLOSURE( X6 ) );
        X6 = X5;
L5303:
        if  ( FALSE( scrt6_eof_2dobject_3f( X6 ) ) )  goto L5304;
        X7 = scrt7_read_2dchar_2dport_v;
        X7 = UNKNOWNCALL( X7, 0 );
        X4 = VIA( PROCEDURE_CODE( X7 ) )( PROCEDURE_CLOSURE( X7 ) );
        goto L5313;
L5304:
        if  ( NOT( OR( EQ( X6, C_CHAR( 040 ) ), 
                       AND( GTE( X6, C_CHAR( 011 ) ), 
                            LTE( X6, C_CHAR( 015 ) ) ) ) ) )  goto L5306;
        X7 = scrt7_read_2dchar_2dport_v;
        X7 = UNKNOWNCALL( X7, 0 );
        VIA( PROCEDURE_CODE( X7 ) )( PROCEDURE_CLOSURE( X7 ) );
        X7 = scrt7_peek_2dchar_2dport_v;
        X7 = UNKNOWNCALL( X7, 0 );
        X6 = VIA( PROCEDURE_CODE( X7 ) )( PROCEDURE_CLOSURE( X7 ) );
        GOBACK( L5303 );
L5306:
        if  ( AND( EQ( TSCPIMMEDIATETAG( X6 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 15122 ) ), 
                       CHARACTERTAG ) ) )  goto L5310;
        X7 = CONS( _TSCP( 15122 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X6, X7 ) );
L5310:
        if  ( NEQ( _S2CINT( X6 ), 
                   _S2CINT( _TSCP( 15122 ) ) ) )  goto L5312;
L5314:
        X7 = scrt7_next_2dchar(  );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X7 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 2578 ) ), 
                       CHARACTERTAG ) ) )  goto L5318;
        X8 = CONS( _TSCP( 2578 ), EMPTYLIST );
        scdebug_error( c2174, c2175, CONS( X7, X8 ) );
L5318:
        if  ( NEQ( _S2CINT( X7 ), _S2CINT( _TSCP( 2578 ) ) ) )  GOBACK( L5314 );
        X7 = scrt7_peek_2dchar_2dport_v;
        X7 = UNKNOWNCALL( X7, 0 );
        X6 = VIA( PROCEDURE_CODE( X7 ) )( PROCEDURE_CLOSURE( X7 ) );
        GOBACK( L5303 );
L5312:
        X7 = scrt7_token(  );
        X4 = scrt7_datum( X7 );
L5313:
        scrt7_ort_2dproc_ae18f815_v = X1;
        scrt7_peek_2dchar_2dport_v = X3;
        scrt7_read_2dchar_2dport_v = X2;
        POPSTACKTRACE( X4 );
}

DEFTSCP( scrt7_datum_v );
DEFCSTRING( t5323, "SCRT7_DATUM" );
EXTERNTSCPP( scrt7_datum_2dlist, XAL1( TSCP ) );
EXTERNTSCP( scrt7_datum_2dlist_v );
EXTERNTSCPP( scrt4_list_2d_3evector, XAL1( TSCP ) );
EXTERNTSCP( scrt4_list_2d_3evector_v );
EXTERNTSCPP( scrt7_datum_2dvector, XAL1( TSCP ) );
EXTERNTSCP( scrt7_datum_2dvector_v );
EXTERNTSCP( scrt4__25record_2dread_v );

TSCP  scrt7_datum( c3143 )
        TSCP  c3143;
{
        TSCP  X4, X3, X2, X1;

        PUSHSTACKTRACE( t5323 );
        if  ( NEQ( _S2CUINT( c3143 ), 
                   _S2CUINT( scrt7_token_2dleft_2dparen_v ) )
            )  goto L5325;
        X1 = scrt7_token(  );
        POPSTACKTRACE( scrt7_datum_2dlist( X1 ) );
L5325:
        if  ( NEQ( _S2CUINT( c3143 ), 
                   _S2CUINT( scrt7_token_2dvector_v ) ) )  goto L5327;
        X2 = scrt7_token(  );
        X1 = scrt7_datum_2dvector( X2 );
        POPSTACKTRACE( scrt4_list_2d_3evector( X1 ) );
L5327:
        if  ( NEQ( _S2CUINT( c3143 ), 
                   _S2CUINT( scrt7_token_2dquote_v ) ) )  goto L5329;
        X4 = scrt7_token(  );
        X3 = scrt7_datum( X4 );
        X2 = sc_cons( X3, EMPTYLIST );
        X1 = sc_cons( c2135, X2 );
        POPSTACKTRACE( X1 );
L5329:
        if  ( NEQ( _S2CUINT( c3143 ), 
                   _S2CUINT( scrt7_token_2dquasiquote_v ) ) )  goto L5332;
        X4 = scrt7_token(  );
        X3 = scrt7_datum( X4 );
        X2 = sc_cons( X3, EMPTYLIST );
        X1 = sc_cons( c2137, X2 );
        POPSTACKTRACE( X1 );
L5332:
        if  ( NEQ( _S2CUINT( c3143 ), 
                   _S2CUINT( scrt7_token_2dunquote_v ) ) )  goto L5335;
        X4 = scrt7_token(  );
        X3 = scrt7_datum( X4 );
        X2 = sc_cons( X3, EMPTYLIST );
        X1 = sc_cons( c2141, X2 );
        POPSTACKTRACE( X1 );
L5335:
        if  ( NEQ( _S2CUINT( c3143 ), 
                   _S2CUINT( scrt7_2dsplicing_542533dd_v ) ) )  goto L5338;
        X4 = scrt7_token(  );
        X3 = scrt7_datum( X4 );
        X2 = sc_cons( X3, EMPTYLIST );
        X1 = sc_cons( c2139, X2 );
        POPSTACKTRACE( X1 );
L5338:
        if  ( NEQ( TSCPTAG( c3143 ), PAIRTAG ) )  goto L5341;
        if  ( NEQ( _S2CUINT( c3143 ), 
                   _S2CUINT( scrt7_token_2drecord_v ) ) )  goto L5343;
        X2 = sc_cons( c3168, scrt7_ort_2dproc_ae18f815_v );
        X1 = scrt4__25record_2dread_v;
        X1 = UNKNOWNCALL( X1, 1 );
        POPSTACKTRACE( VIA( PROCEDURE_CODE( X1 ) )( X2, 
                                                    PROCEDURE_CLOSURE( X1 ) ) );
L5343:
        POPSTACKTRACE( scdebug_error( c2155, 
                                      c3167, 
                                      CONS( c3143, EMPTYLIST ) ) );
L5341:
        POPSTACKTRACE( c3143 );
}

DEFTSCP( scrt7_datum_2dlist_v );
DEFCSTRING( t5345, "SCRT7_DATUM-LIST" );

TSCP  scrt7_datum_2dlist( c3180 )
        TSCP  c3180;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( t5345 );
        if  ( EQ( _S2CUINT( c3180 ), 
                  _S2CUINT( scrt7_token_2dright_2dparen_v ) )
            )  goto L5347;
        if  ( NEQ( _S2CUINT( c3180 ), 
                   _S2CUINT( scrt7_token_2dperiod_v ) ) )  goto L5349;
        X2 = scrt7_token(  );
        X1 = scrt7_datum( X2 );
        X2 = scrt7_token(  );
        if  ( EQ( _S2CUINT( X2 ), 
                  _S2CUINT( scrt7_token_2dright_2dparen_v ) )
            )  goto L5352;
        POPSTACKTRACE( scdebug_error( c2155, c3192, EMPTYLIST ) );
L5352:
        POPSTACKTRACE( X1 );
L5349:
        X1 = scrt7_datum( c3180 );
        X3 = scrt7_token(  );
        X2 = scrt7_datum_2dlist( X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L5347:
        POPSTACKTRACE( EMPTYLIST );
}

DEFTSCP( scrt7_datum_2dvector_v );
DEFCSTRING( t5354, "SCRT7_DATUM-VECTOR" );

TSCP  scrt7_datum_2dvector( c3194 )
        TSCP  c3194;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( t5354 );
        if  ( EQ( _S2CUINT( c3194 ), 
                  _S2CUINT( scrt7_token_2dright_2dparen_v ) )
            )  goto L5356;
        X1 = scrt7_datum( c3194 );
        X3 = scrt7_token(  );
        X2 = scrt7_datum_2dvector( X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L5356:
        POPSTACKTRACE( EMPTYLIST );
}

DEFTSCP( scrt7_write_2dtoken_2dport_v );
DEFCSTRING( t5358, "SCRT7_WRITE-TOKEN-PORT" );
DEFTSCP( scrt7_write_2dlength_2dport_v );
DEFCSTRING( t5359, "SCRT7_WRITE-LENGTH-PORT" );
DEFTSCP( scrt7_write_2dwidth_2dport_v );
DEFCSTRING( t5360, "SCRT7_WRITE-WIDTH-PORT" );
DEFTSCP( scrt7_ort_2dproc_61a60f78_v );
DEFCSTRING( t5361, "SCRT7_WRITE/DISPLAY-PORT-PROC" );
DEFTSCP( scrt7_write_2fdisplay_v );
DEFCSTRING( t5362, "SCRT7_WRITE/DISPLAY" );
EXTERNTSCPP( scrt7_write_2fdisplay2, 
             XAL6( TSCP, TSCP, TSCP, TSCP, TSCP, TSCP ) );
EXTERNTSCP( scrt7_write_2fdisplay2_v );

TSCP  scrt7_write_2fdisplay( o3203, r3204, p3205 )
        TSCP  o3203, r3204, p3205;
{
        TSCP  X10, 
              X9, 
              X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t5362 );
        X1 = scrt7_ort_2dproc_61a60f78_v;
        X2 = scrt7_write_2dwidth_2dport_v;
        X3 = scrt7_write_2dlength_2dport_v;
        X4 = scrt7_write_2dtoken_2dport_v;
        X5 = p3205;
        X5 = UNKNOWNCALL( X5, 1 );
        scrt7_write_2dtoken_2dport_v = VIA( PROCEDURE_CODE( X5 ) )( c3211, 
                                                                    PROCEDURE_CLOSURE( X5 ) );
        X6 = p3205;
        X6 = UNKNOWNCALL( X6, 1 );
        X5 = VIA( PROCEDURE_CODE( X6 ) )( c3212, 
                                          PROCEDURE_CLOSURE( X6 ) );
        X5 = UNKNOWNCALL( X5, 0 );
        scrt7_write_2dlength_2dport_v = VIA( PROCEDURE_CODE( X5 ) )( PROCEDURE_CLOSURE( X5 ) );
        X6 = p3205;
        X6 = UNKNOWNCALL( X6, 1 );
        X5 = VIA( PROCEDURE_CODE( X6 ) )( c3213, 
                                          PROCEDURE_CLOSURE( X6 ) );
        X5 = UNKNOWNCALL( X5, 0 );
        scrt7_write_2dwidth_2dport_v = VIA( PROCEDURE_CODE( X5 ) )( PROCEDURE_CLOSURE( X5 ) );
        scrt7_ort_2dproc_61a60f78_v = p3205;
        X8 = p3205;
        X8 = UNKNOWNCALL( X8, 1 );
        X7 = VIA( PROCEDURE_CODE( X8 ) )( c3217, 
                                          PROCEDURE_CLOSURE( X8 ) );
        X7 = UNKNOWNCALL( X7, 0 );
        if  ( FALSE( VIA( PROCEDURE_CODE( X7 ) )( PROCEDURE_CLOSURE( X7 ) ) )
            )  goto L5365;
        X6 = _TSCP( 0 );
        goto L5366;
L5365:
        X6 = FALSEVALUE;
L5366:
        X9 = p3205;
        X9 = UNKNOWNCALL( X9, 1 );
        X8 = VIA( PROCEDURE_CODE( X9 ) )( c3218, 
                                          PROCEDURE_CLOSURE( X9 ) );
        X8 = UNKNOWNCALL( X8, 0 );
        X7 = VIA( PROCEDURE_CODE( X8 ) )( PROCEDURE_CLOSURE( X8 ) );
        X10 = p3205;
        X10 = UNKNOWNCALL( X10, 1 );
        X9 = VIA( PROCEDURE_CODE( X10 ) )( c3219, 
                                           PROCEDURE_CLOSURE( X10 ) );
        X9 = UNKNOWNCALL( X9, 0 );
        if  ( FALSE( VIA( PROCEDURE_CODE( X9 ) )( PROCEDURE_CLOSURE( X9 ) ) )
            )  goto L5367;
        X8 = EMPTYLIST;
        goto L5368;
L5367:
        X8 = FALSEVALUE;
L5368:
        X5 = scrt7_write_2fdisplay2( o3203, 
                                     r3204, 
                                     X6, 
                                     X7, 
                                     scrt7_write_2dlength_2dport_v, X8 );
        scrt7_write_2dtoken_2dport_v = X4;
        scrt7_write_2dlength_2dport_v = X3;
        scrt7_write_2dwidth_2dport_v = X2;
        scrt7_ort_2dproc_61a60f78_v = X1;
        POPSTACKTRACE( X5 );
}

DEFTSCP( scrt7_write_2fdisplay2_v );
DEFCSTRING( t5370, "SCRT7_WRITE/DISPLAY2" );
EXTERNTSCPP( scrt7_readable_2dsymbol, XAL1( TSCP ) );
EXTERNTSCP( scrt7_readable_2dsymbol_v );
EXTERNTSCPP( scrt7_fixed_2d_3eclist, XAL1( TSCP ) );
EXTERNTSCP( scrt7_fixed_2d_3eclist_v );
EXTERNTSCPP( scrt7_readable_2dstring, XAL1( TSCP ) );
EXTERNTSCP( scrt7_readable_2dstring_v );
EXTERNTSCPP( scrt7_readable_2dchar, XAL1( TSCP ) );
EXTERNTSCP( scrt7_readable_2dchar_v );
EXTERNTSCPP( scrt4_vector_2d_3elist, XAL1( TSCP ) );
EXTERNTSCP( scrt4_vector_2d_3elist_v );
EXTERNTSCPP( scrt7_float_2d_3estring, XAL1( TSCP ) );
EXTERNTSCP( scrt7_float_2d_3estring_v );
EXTERNTSCP( sc_undefined );
EXTERNTSCPP( scrt4_p_2dmethod_3ccf392b, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt4_p_2dmethod_3ccf392b_v );
EXTERNTSCPP( scrt1_length, XAL1( TSCP ) );
EXTERNTSCP( scrt1_length_v );

TSCP  scrt7_c3235( x3237, c5503 )
        TSCP  x3237, c5503;
{
        TSCP  X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( "COUNT-CHAR [inside WRITE/DISPLAY2]" );
        X1 = DISPLAY( 0 );
        DISPLAY( 0 ) = CLOSURE_VAR( c5503, 0 );
        X4 = PAIR_CAR( DISPLAY( 0 ) );
        if  ( NOT( AND( EQ( TSCPTAG( x3237 ), EXTENDEDTAG ), 
                        EQ( TSCP_EXTENDEDTAG( x3237 ), STRINGTAG ) ) )
            )  goto L5505;
        X6 = C_FIXED( STRING_LENGTH( x3237 ) );
        goto L5506;
L5505:
        X6 = FALSEVALUE;
L5506:
        if  ( FALSE( X6 ) )  goto L5509;
        X5 = X6;
        goto L5515;
L5509:
        if  ( NEQ( TSCPTAG( x3237 ), PAIRTAG ) )  goto L5511;
        X7 = scrt1_length( x3237 );
        goto L5512;
L5511:
        X7 = FALSEVALUE;
L5512:
        if  ( FALSE( X7 ) )  goto L5514;
        X5 = X7;
        goto L5515;
L5514:
        X5 = _TSCP( 4 );
L5515:
        if  ( BITAND( BITOR( _S2CINT( X5 ), _S2CINT( X4 ) ), 
                      3 ) )  goto L5517;
        X3 = _TSCP( IPLUS( _S2CINT( X5 ), _S2CINT( X4 ) ) );
        goto L5518;
L5517:
        X3 = scrt2__2b_2dtwo( X5, X4 );
L5518:
        X2 = SETGEN( PAIR_CAR( DISPLAY( 0 ) ), X3 );
        DISPLAY( 0 ) = X1;
        POPSTACKTRACE( X2 );
}

EXTERNTSCPP( scrt2__3c_3d_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2__3c_3d_2dtwo_v );
EXTERNTSCPP( scrt7_write_2fdisplay_2dlist, 
             XAL6( TSCP, TSCP, TSCP, TSCP, TSCP, TSCP ) );
EXTERNTSCP( scrt7_write_2fdisplay_2dlist_v );

TSCP  scrt7_write_2fdisplay2( o3221, 
                              r3222, 
                              i3223, w3224, w3225, c3226 )
        TSCP  o3221, r3222, i3223, w3224, w3225, c3226;
{
        TSCP  X7, X6, X5, X4, X3, X2, X1;
        TSCP  SD0 = DISPLAY( 0 );
        TSCP  SDVAL;

        PUSHSTACKTRACE( t5370 );
L5371:
        X1 = BOOLEAN( EQ( _S2CUINT( w3224 ), 
                          _S2CUINT( _TSCP( 0 ) ) ) );
        if  ( FALSE( X1 ) )  goto L5387;
        if  ( EQ( TSCPTAG( o3221 ), PAIRTAG ) )  goto L5380;
        if  ( AND( EQ( TSCPTAG( o3221 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( o3221 ), VECTORTAG ) )
            )  goto L5380;
        if  ( AND( EQ( TSCPTAG( o3221 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( o3221 ), RECORDTAG ) )
            )  goto L5380;
L5387:
        X1 = BOOLEAN( NEQ( _S2CUINT( c3226 ), 
                           _S2CUINT( FALSEVALUE ) ) );
        if  ( FALSE( X1 ) )  goto L5403;
        if  ( NEQ( TSCPTAG( o3221 ), PAIRTAG ) )  goto L5392;
        X2 = TRUEVALUE;
        goto L5395;
L5392:
        if  ( NOT( AND( EQ( TSCPTAG( o3221 ), EXTENDEDTAG ), 
                        EQ( TSCP_EXTENDEDTAG( o3221 ), VECTORTAG ) ) )
            )  goto L5394;
        X2 = TRUEVALUE;
        goto L5395;
L5394:
        X2 = BOOLEAN( AND( EQ( TSCPTAG( o3221 ), EXTENDEDTAG ), 
                           EQ( TSCP_EXTENDEDTAG( o3221 ), 
                               RECORDTAG ) ) );
L5395:
        if  ( FALSE( X2 ) )  goto L5403;
        if  ( FALSE( scrt1_memq( o3221, c3226 ) ) )  goto L5403;
        X3 = scrt7_write_2dtoken_2dport_v;
        X3 = UNKNOWNCALL( X3, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X3 ) )( c3596, 
                                             PROCEDURE_CLOSURE( X3 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5380:
        X1 = scrt7_write_2dtoken_2dport_v;
        X1 = UNKNOWNCALL( X1, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X1 ) )( c3397, 
                                             PROCEDURE_CLOSURE( X1 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5403:
        if  ( NEQ( TSCPTAG( o3221 ), PAIRTAG ) )  goto L5404;
        X2 = PAIR_CDR( o3221 );
        if  ( NEQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L5406;
        X3 = PAIR_CDR( o3221 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L5413;
        scrt1__24__cdr_2derror( X3 );
L5413:
        X2 = PAIR_CDR( X3 );
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( EMPTYLIST ) ) )  goto L5409;
        X2 = PAIR_CAR( o3221 );
        X1 = scrt1_assq( X2, c3595 );
        goto L5407;
L5409:
        X1 = FALSEVALUE;
        goto L5407;
L5406:
        X1 = FALSEVALUE;
L5407:
        if  ( NEQ( _S2CUINT( scrt7_write_2dlength_2dport_v ), 
                   _S2CUINT( _TSCP( 0 ) ) ) )  goto L5417;
        X2 = scrt7_write_2dtoken_2dport_v;
        X2 = UNKNOWNCALL( X2, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X2 ) )( c3561, 
                                             PROCEDURE_CLOSURE( X2 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5417:
        if  ( FALSE( X1 ) )  goto L5435;
        if  ( FALSE( r3222 ) )  goto L5435;
        if  ( EQ( TSCPTAG( X1 ), PAIRTAG ) )  goto L5426;
        scrt1__24__cdr_2derror( X1 );
L5426:
        X4 = PAIR_CDR( X1 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto L5429;
        scrt1__24__car_2derror( X4 );
L5429:
        X3 = PAIR_CAR( X4 );
        X2 = scrt7_write_2dtoken_2dport_v;
        X2 = UNKNOWNCALL( X2, 1 );
        VIA( PROCEDURE_CODE( X2 ) )( X3, PROCEDURE_CLOSURE( X2 ) );
        X3 = PAIR_CDR( o3221 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L5433;
        scrt1__24__car_2derror( X3 );
L5433:
        X2 = PAIR_CAR( X3 );
        o3221 = X2;
        GOBACK( L5371 );
L5404:
        if  ( NOT( AND( EQ( TSCPTAG( o3221 ), EXTENDEDTAG ), 
                        EQ( TSCP_EXTENDEDTAG( o3221 ), SYMBOLTAG ) ) )
            )  goto L5436;
        if  ( FALSE( r3222 ) )  goto L5438;
        if  ( FALSE( scrt1_memq( o3221, c3424 ) ) )  goto L5440;
        X2 = SYMBOL_NAME( o3221 );
        X1 = scrt7_write_2dtoken_2dport_v;
        X1 = UNKNOWNCALL( X1, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X1 ) )( X2, 
                                             PROCEDURE_CLOSURE( X1 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5440:
        X2 = scrt7_readable_2dsymbol( o3221 );
        X1 = scrt7_write_2dtoken_2dport_v;
        X1 = UNKNOWNCALL( X1, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X1 ) )( X2, 
                                             PROCEDURE_CLOSURE( X1 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5438:
        X2 = SYMBOL_NAME( o3221 );
        X1 = scrt7_write_2dtoken_2dport_v;
        X1 = UNKNOWNCALL( X1, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X1 ) )( X2, 
                                             PROCEDURE_CLOSURE( X1 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5436:
        if  ( NEQ( TSCPTAG( o3221 ), FIXNUMTAG ) )  goto L5444;
        X2 = scrt7_fixed_2d_3eclist( o3221 );
        X1 = scrt7_write_2dtoken_2dport_v;
        X1 = UNKNOWNCALL( X1, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X1 ) )( X2, 
                                             PROCEDURE_CLOSURE( X1 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5444:
        if  ( NOT( AND( EQ( TSCPTAG( o3221 ), EXTENDEDTAG ), 
                        EQ( TSCP_EXTENDEDTAG( o3221 ), STRINGTAG ) ) )
            )  goto L5446;
        if  ( FALSE( r3222 ) )  goto L5448;
        X2 = scrt7_readable_2dstring( o3221 );
        goto L5449;
L5448:
        X2 = o3221;
L5449:
        X1 = scrt7_write_2dtoken_2dport_v;
        X1 = UNKNOWNCALL( X1, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X1 ) )( X2, 
                                             PROCEDURE_CLOSURE( X1 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5446:
        if  ( NEQ( TSCPIMMEDIATETAG( o3221 ), CHARACTERTAG ) )  goto L5450;
        if  ( FALSE( r3222 ) )  goto L5452;
        X2 = scrt7_readable_2dchar( o3221 );
        goto L5453;
L5452:
        X2 = o3221;
L5453:
        X1 = scrt7_write_2dtoken_2dport_v;
        X1 = UNKNOWNCALL( X1, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X1 ) )( X2, 
                                             PROCEDURE_CLOSURE( X1 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5450:
        X1 = BOOLEAN( AND( EQ( TSCPTAG( o3221 ), EXTENDEDTAG ), 
                           EQ( TSCP_EXTENDEDTAG( o3221 ), 
                               STRINGTAG ) ) );
        if  ( TRUE( X1 ) )  goto L5458;
        if  ( NOT( AND( EQ( TSCPTAG( o3221 ), EXTENDEDTAG ), 
                        EQ( TSCP_EXTENDEDTAG( o3221 ), VECTORTAG ) ) )
            )  goto L5459;
        X2 = scrt7_write_2dtoken_2dport_v;
        X2 = UNKNOWNCALL( X2, 1 );
        VIA( PROCEDURE_CODE( X2 ) )( c3397, 
                                     PROCEDURE_CLOSURE( X2 ) );
        X2 = scrt4_vector_2d_3elist( o3221 );
        if  ( FALSE( i3223 ) )  goto L5462;
        if  ( BITAND( BITOR( _S2CINT( i3223 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L5464;
        X3 = _TSCP( IPLUS( _S2CINT( i3223 ), 
                           _S2CINT( _TSCP( 4 ) ) ) );
        goto L5463;
L5464:
        X3 = scrt2__2b_2dtwo( i3223, _TSCP( 4 ) );
        goto L5463;
L5462:
        X3 = i3223;
L5463:
        if  ( EQ( _S2CUINT( c3226 ), 
                  _S2CUINT( FALSEVALUE ) ) )  goto L5466;
        c3226 = sc_cons( o3221, c3226 );
        goto L5467;
L5466:
        c3226 = FALSEVALUE;
L5467:
        i3223 = X3;
        o3221 = X2;
        GOBACK( L5371 );
L5459:
        if  ( NOT( AND( EQ( TSCPTAG( o3221 ), EXTENDEDTAG ), 
                        EQ( TSCP_EXTENDEDTAG( o3221 ), 
                            DOUBLEFLOATTAG ) ) ) )  goto L5468;
        X3 = scrt7_float_2d_3estring( o3221 );
        X2 = scrt7_write_2dtoken_2dport_v;
        X2 = UNKNOWNCALL( X2, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X2 ) )( X3, 
                                             PROCEDURE_CLOSURE( X2 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5468:
        if  ( NEQ( _S2CUINT( o3221 ), 
                   _S2CUINT( TRUEVALUE ) ) )  goto L5470;
        X2 = scrt7_write_2dtoken_2dport_v;
        X2 = UNKNOWNCALL( X2, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X2 ) )( c3394, 
                                             PROCEDURE_CLOSURE( X2 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5470:
        if  ( NEQ( _S2CUINT( o3221 ), 
                   _S2CUINT( FALSEVALUE ) ) )  goto L5472;
        X2 = scrt7_write_2dtoken_2dport_v;
        X2 = UNKNOWNCALL( X2, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X2 ) )( c3393, 
                                             PROCEDURE_CLOSURE( X2 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5472:
        if  ( NEQ( _S2CUINT( o3221 ), 
                   _S2CUINT( EMPTYLIST ) ) )  goto L5474;
        X2 = scrt7_write_2dtoken_2dport_v;
        X2 = UNKNOWNCALL( X2, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X2 ) )( c3392, 
                                             PROCEDURE_CLOSURE( X2 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5474:
        if  ( FALSE( scrt6_eof_2dobject_3f( o3221 ) ) )  goto L5476;
        X2 = scrt7_write_2dtoken_2dport_v;
        X2 = UNKNOWNCALL( X2, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X2 ) )( c3391, 
                                             PROCEDURE_CLOSURE( X2 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5476:
        if  ( NEQ( _S2CUINT( o3221 ), 
                   _S2CUINT( sc_undefined ) ) )  goto L5478;
        X2 = scrt7_write_2dtoken_2dport_v;
        X2 = UNKNOWNCALL( X2, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X2 ) )( c3390, 
                                             PROCEDURE_CLOSURE( X2 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5478:
        if  ( NOT( AND( EQ( TSCPTAG( o3221 ), EXTENDEDTAG ), 
                        EQ( TSCP_EXTENDEDTAG( o3221 ), 
                            PROCEDURETAG ) ) ) )  goto L5480;
        X2 = scrt7_write_2dtoken_2dport_v;
        X2 = UNKNOWNCALL( X2, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X2 ) )( c3389, 
                                             PROCEDURE_CLOSURE( X2 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5480:
        if  ( NOT( AND( EQ( TSCPTAG( o3221 ), EXTENDEDTAG ), 
                        EQ( TSCP_EXTENDEDTAG( o3221 ), RECORDTAG ) ) )
            )  goto L5482;
        if  ( FALSE( r3222 ) )  goto L5484;
        X3 = c3388;
        goto L5485;
L5484:
        X3 = c3387;
L5485:
        X2 = scrt4_p_2dmethod_3ccf392b( o3221, X3 );
        X5 = sc_cons( c3168, scrt7_ort_2dproc_61a60f78_v );
        X4 = X2;
        X4 = UNKNOWNCALL( X4, 6 );
        X3 = VIA( PROCEDURE_CODE( X4 ) )( o3221, 
                                          X5, 
                                          i3223, 
                                          w3224, 
                                          w3225, 
                                          c3226, 
                                          PROCEDURE_CLOSURE( X4 ) );
        if  ( NEQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L5488;
        X4 = PAIR_CAR( X3 );
        if  ( FALSE( i3223 ) )  goto L5491;
        if  ( BITAND( BITOR( _S2CINT( i3223 ), 
                             _S2CINT( _TSCP( 8 ) ) ), 
                      3 ) )  goto L5493;
        X5 = _TSCP( IPLUS( _S2CINT( i3223 ), 
                           _S2CINT( _TSCP( 8 ) ) ) );
        goto L5492;
L5493:
        X5 = scrt2__2b_2dtwo( i3223, _TSCP( 8 ) );
        goto L5492;
L5491:
        X5 = i3223;
L5492:
        if  ( EQ( _S2CUINT( c3226 ), 
                  _S2CUINT( FALSEVALUE ) ) )  goto L5495;
        c3226 = sc_cons( o3221, c3226 );
        goto L5496;
L5495:
        c3226 = FALSEVALUE;
L5496:
        i3223 = X5;
        o3221 = X4;
        GOBACK( L5371 );
L5488:
        SDVAL = FALSEVALUE;
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5482:
        X2 = scrt7_write_2dtoken_2dport_v;
        X2 = UNKNOWNCALL( X2, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X2 ) )( c3359, 
                                             PROCEDURE_CLOSURE( X2 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5435:
        if  ( FALSE( i3223 ) )  goto L5536;
        X3 = o3221;
        DISPLAY( 0 ) = _TSCP( 0 );
        X4 = scrt7_write_2dtoken_2dport_v;
        DISPLAY( 0 ) = CONS( DISPLAY( 0 ), EMPTYLIST );
        X5 = _TSCP( 0 );
        X5 = CONS( X5, EMPTYLIST );
        X6 = MAKEPROCEDURE( 1, 
                            0, 
                            scrt7_c3235, 
                            MAKECLOSURE( EMPTYLIST, 
                                         1, DISPLAY( 0 ) ) );
        SETGEN( PAIR_CAR( X5 ), X6 );
        scrt7_write_2dtoken_2dport_v = PAIR_CAR( X5 );
        if  ( FALSE( w3224 ) )  goto L5519;
        X6 = w3224;
        goto L5520;
L5519:
        X6 = _TSCP( 200 );
L5520:
        if  ( FALSE( w3225 ) )  goto L5521;
        X7 = w3225;
        goto L5522;
L5521:
        X7 = _TSCP( 200 );
L5522:
        scrt7_write_2fdisplay2( X3, 
                                r3222, 
                                FALSEVALUE, X6, X7, c3226 );
        scrt7_write_2dtoken_2dport_v = X4;
        X2 = PAIR_CAR( DISPLAY( 0 ) );
        if  ( BITAND( BITOR( _S2CINT( i3223 ), 
                             _S2CINT( X2 ) ), 
                      3 ) )  goto L5524;
        X1 = _TSCP( IPLUS( _S2CINT( i3223 ), _S2CINT( X2 ) ) );
        goto L5525;
L5524:
        X1 = scrt2__2b_2dtwo( i3223, X2 );
L5525:
        X2 = scrt7_write_2dwidth_2dport_v;
        if  ( BITAND( BITOR( _S2CINT( X1 ), _S2CINT( X2 ) ), 
                      3 ) )  goto L5528;
        if  ( LTE( _S2CINT( X1 ), _S2CINT( X2 ) ) )  goto L5532;
        goto L5536;
L5528:
        if  ( FALSE( scrt2__3c_3d_2dtwo( X1, X2 ) ) )  goto L5536;
L5532:
        i3223 = FALSEVALUE;
        GOBACK( L5371 );
L5458:
        X1 = scrt7_write_2dtoken_2dport_v;
        X1 = UNKNOWNCALL( X1, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X1 ) )( o3221, 
                                             PROCEDURE_CLOSURE( X1 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5536:
        X1 = scrt7_write_2dtoken_2dport_v;
        X1 = UNKNOWNCALL( X1, 1 );
        VIA( PROCEDURE_CODE( X1 ) )( c3456, 
                                     PROCEDURE_CLOSURE( X1 ) );
        X1 = PAIR_CAR( o3221 );
        if  ( FALSE( i3223 ) )  goto L5539;
        if  ( BITAND( BITOR( _S2CINT( i3223 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L5541;
        X2 = _TSCP( IPLUS( _S2CINT( i3223 ), 
                           _S2CINT( _TSCP( 4 ) ) ) );
        goto L5540;
L5541:
        X2 = scrt2__2b_2dtwo( i3223, _TSCP( 4 ) );
        goto L5540;
L5539:
        X2 = i3223;
L5540:
        if  ( FALSE( w3224 ) )  goto L5543;
        if  ( BITAND( BITOR( _S2CINT( w3224 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L5545;
        X3 = _TSCP( IDIFFERENCE( _S2CINT( w3224 ), 
                                 _S2CINT( _TSCP( 4 ) ) ) );
        goto L5544;
L5545:
        X3 = scrt2__2d_2dtwo( w3224, _TSCP( 4 ) );
        goto L5544;
L5543:
        X3 = w3224;
L5544:
        X5 = scrt7_write_2dlength_2dport_v;
        if  ( FALSE( X5 ) )  goto L5548;
        X6 = scrt7_write_2dlength_2dport_v;
        if  ( BITAND( BITOR( _S2CINT( X6 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L5551;
        X4 = _TSCP( IDIFFERENCE( _S2CINT( X6 ), 
                                 _S2CINT( _TSCP( 4 ) ) ) );
        goto L5549;
L5551:
        X4 = scrt2__2d_2dtwo( X6, _TSCP( 4 ) );
        goto L5549;
L5548:
        X4 = X5;
L5549:
        if  ( EQ( _S2CUINT( c3226 ), 
                  _S2CUINT( FALSEVALUE ) ) )  goto L5553;
        X5 = sc_cons( o3221, c3226 );
        goto L5554;
L5553:
        X5 = FALSEVALUE;
L5554:
        scrt7_write_2fdisplay2( X1, 
                                r3222, X2, X3, X4, X5 );
        X1 = PAIR_CDR( o3221 );
        if  ( FALSE( i3223 ) )  goto L5556;
        if  ( BITAND( BITOR( _S2CINT( i3223 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L5558;
        X2 = _TSCP( IPLUS( _S2CINT( i3223 ), 
                           _S2CINT( _TSCP( 4 ) ) ) );
        goto L5557;
L5558:
        X2 = scrt2__2b_2dtwo( i3223, _TSCP( 4 ) );
        goto L5557;
L5556:
        X2 = i3223;
L5557:
        if  ( FALSE( w3224 ) )  goto L5560;
        if  ( BITAND( BITOR( _S2CINT( w3224 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L5562;
        X3 = _TSCP( IDIFFERENCE( _S2CINT( w3224 ), 
                                 _S2CINT( _TSCP( 4 ) ) ) );
        goto L5561;
L5562:
        X3 = scrt2__2d_2dtwo( w3224, _TSCP( 4 ) );
        goto L5561;
L5560:
        X3 = w3224;
L5561:
        X5 = scrt7_write_2dlength_2dport_v;
        if  ( FALSE( X5 ) )  goto L5565;
        X6 = scrt7_write_2dlength_2dport_v;
        if  ( BITAND( BITOR( _S2CINT( X6 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L5568;
        X4 = _TSCP( IDIFFERENCE( _S2CINT( X6 ), 
                                 _S2CINT( _TSCP( 4 ) ) ) );
        goto L5566;
L5568:
        X4 = scrt2__2d_2dtwo( X6, _TSCP( 4 ) );
        goto L5566;
L5565:
        X4 = X5;
L5566:
        if  ( EQ( _S2CUINT( c3226 ), 
                  _S2CUINT( FALSEVALUE ) ) )  goto L5570;
        X5 = sc_cons( o3221, c3226 );
        goto L5571;
L5570:
        X5 = FALSEVALUE;
L5571:
        SDVAL = scrt7_write_2fdisplay_2dlist( X1, 
                                              r3222, 
                                              X2, X3, X4, X5 );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
}

DEFTSCP( scrt7_write_2fdisplay_2dlist_v );
DEFCSTRING( t5572, "SCRT7_WRITE/DISPLAY-LIST" );
EXTERNTSCPP( scrt3_substring, XAL3( TSCP, TSCP, TSCP ) );
EXTERNTSCP( scrt3_substring_v );

TSCP  scrt7_p3605( x3607 )
        TSCP  x3607;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( "PRINT [inside WRITE/DISPLAY-LIST]" );
        if  ( FALSE( DISPLAY( 0 ) ) )  goto L5576;
        X1 = scrt7_write_2dtoken_2dport_v;
        X1 = UNKNOWNCALL( X1, 1 );
        VIA( PROCEDURE_CODE( X1 ) )( _TSCP( 2578 ), 
                                     PROCEDURE_CLOSURE( X1 ) );
        X1 = DISPLAY( 0 );
L5580:
        if  ( NEQ( TSCPTAG( X1 ), FIXNUMTAG ) )  goto L5582;
        if  ( NEQ( _S2CUINT( X1 ), _S2CUINT( _TSCP( 0 ) ) ) )  goto L5586;
        goto L5589;
L5582:
        if  ( TRUE( scrt2_zero_3f( X1 ) ) )  goto L5589;
L5586:
        X2 = scrt7_write_2dtoken_2dport_v;
        X2 = UNKNOWNCALL( X2, 1 );
        VIA( PROCEDURE_CODE( X2 ) )( _TSCP( 8210 ), 
                                     PROCEDURE_CLOSURE( X2 ) );
        if  ( BITAND( BITOR( _S2CINT( X1 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L5591;
        X1 = _TSCP( IDIFFERENCE( _S2CINT( X1 ), 
                                 _S2CINT( _TSCP( 4 ) ) ) );
        GOBACK( L5580 );
L5591:
        X1 = scrt2__2d_2dtwo( X1, _TSCP( 4 ) );
        GOBACK( L5580 );
L5589:
        if  ( AND( EQ( TSCPTAG( x3607 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( x3607 ), STRINGTAG ) )
            )  goto L5594;
        scdebug_error( c3257, 
                       c3258, CONS( x3607, EMPTYLIST ) );
L5594:
        X3 = C_FIXED( STRING_LENGTH( x3607 ) );
        X2 = scrt3_substring( x3607, _TSCP( 4 ), X3 );
        X1 = scrt7_write_2dtoken_2dport_v;
        X1 = UNKNOWNCALL( X1, 1 );
        POPSTACKTRACE( VIA( PROCEDURE_CODE( X1 ) )( X2, 
                                                    PROCEDURE_CLOSURE( X1 ) ) );
L5576:
        X1 = scrt7_write_2dtoken_2dport_v;
        X1 = UNKNOWNCALL( X1, 1 );
        POPSTACKTRACE( VIA( PROCEDURE_CODE( X1 ) )( x3607, 
                                                    PROCEDURE_CLOSURE( X1 ) ) );
}

TSCP  scrt7_write_2fdisplay_2dlist( o3598, 
                                    r3599, 
                                    i3600, w3601, w3602, c3603 )
        TSCP  o3598, r3599, i3600, w3601, w3602, c3603;
{
        TSCP  X2, X1;
        TSCP  SD0 = DISPLAY( 0 );
        TSCP  SDVAL;

        PUSHSTACKTRACE( t5572 );
        DISPLAY( 0 ) = i3600;
L5573:
        if  ( NEQ( _S2CUINT( o3598 ), 
                   _S2CUINT( EMPTYLIST ) ) )  goto L5596;
        X1 = scrt7_write_2dtoken_2dport_v;
        X1 = UNKNOWNCALL( X1, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X1 ) )( c3675, 
                                             PROCEDURE_CLOSURE( X1 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5596:
        if  ( NEQ( _S2CUINT( w3602 ), 
                   _S2CUINT( _TSCP( 0 ) ) ) )  goto L5598;
        SDVAL = scrt7_p3605( c3676 );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5598:
        X1 = BOOLEAN( NEQ( _S2CUINT( c3603 ), 
                           _S2CUINT( FALSEVALUE ) ) );
        if  ( FALSE( X1 ) )  goto L5606;
        if  ( FALSE( scrt1_memq( o3598, c3603 ) ) )  goto L5606;
        SDVAL = scrt7_p3605( c3676 );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L5606:
        if  ( NEQ( TSCPTAG( o3598 ), PAIRTAG ) )  goto L5607;
        scrt7_p3605( c3654 );
        X1 = PAIR_CAR( o3598 );
        scrt7_write_2fdisplay2( X1, 
                                r3599, 
                                DISPLAY( 0 ), 
                                w3601, w3602, c3603 );
        X1 = PAIR_CDR( o3598 );
        if  ( FALSE( w3602 ) )  goto L5612;
        if  ( BITAND( BITOR( _S2CINT( w3602 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L5614;
        X2 = _TSCP( IDIFFERENCE( _S2CINT( w3602 ), 
                                 _S2CINT( _TSCP( 4 ) ) ) );
        goto L5613;
L5614:
        X2 = scrt2__2d_2dtwo( w3602, _TSCP( 4 ) );
        goto L5613;
L5612:
        X2 = w3602;
L5613:
        w3602 = X2;
        o3598 = X1;
        GOBACK( L5573 );
L5607:
        scrt7_p3605( c3674 );
        scrt7_write_2fdisplay2( o3598, 
                                r3599, 
                                DISPLAY( 0 ), 
                                w3601, w3602, c3603 );
        X1 = scrt7_write_2dtoken_2dport_v;
        X1 = UNKNOWNCALL( X1, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X1 ) )( c3675, 
                                             PROCEDURE_CLOSURE( X1 ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
}

DEFTSCP( scrt7_readable_2dchar_v );
DEFCSTRING( t5617, "SCRT7_READABLE-CHAR" );
EXTERNTSCPP( scrt1_assoc, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt1_assoc_v );

TSCP  scrt7_readable_2dchar( o3678 )
        TSCP  o3678;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t5617 );
        if  ( AND( EQ( TSCPIMMEDIATETAG( o3678 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 8210 ) ), 
                       CHARACTERTAG ) ) )  goto L5620;
        X2 = CONS( _TSCP( 8210 ), EMPTYLIST );
        scdebug_error( c3688, c2175, CONS( o3678, X2 ) );
L5620:
        X1 = BOOLEAN( GT( _S2CINT( o3678 ), 
                          _S2CINT( _TSCP( 8210 ) ) ) );
        if  ( FALSE( X1 ) )  goto L5632;
        if  ( AND( EQ( TSCPIMMEDIATETAG( o3678 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 32274 ) ), 
                       CHARACTERTAG ) ) )  goto L5627;
        X2 = CONS( _TSCP( 32274 ), EMPTYLIST );
        scdebug_error( c3696, c2175, CONS( o3678, X2 ) );
L5627:
        if  ( GT( _S2CINT( o3678 ), 
                  _S2CINT( _TSCP( 32274 ) ) ) )  goto L5632;
        X5 = sc_cons( o3678, EMPTYLIST );
        X4 = sc_cons( _TSCP( 23570 ), X5 );
        X3 = sc_cons( _TSCP( 8978 ), X4 );
        X2 = X3;
        POPSTACKTRACE( scrt3_list_2d_3estring( X2 ) );
L5632:
        X1 = scrt1_assoc( o3678, c3711 );
        if  ( FALSE( X1 ) )  goto L5634;
        if  ( EQ( TSCPTAG( X1 ), PAIRTAG ) )  goto L5637;
        scrt1__24__cdr_2derror( X1 );
L5637:
        X2 = PAIR_CDR( X1 );
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L5640;
        scrt1__24__car_2derror( X2 );
L5640:
        POPSTACKTRACE( PAIR_CAR( X2 ) );
L5634:
        POPSTACKTRACE( c3700 );
}

DEFTSCP( scrt7_readable_2dstring_v );
DEFCSTRING( t5642, "SCRT7_READABLE-STRING" );

TSCP  scrt7_readable_2dstring( o3715 )
        TSCP  o3715;
{
        TSCP  X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t5642 );
        X1 = c3824;
        if  ( AND( EQ( TSCPTAG( o3715 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( o3715 ), STRINGTAG ) )
            )  goto L5646;
        scdebug_error( c3257, 
                       c3258, CONS( o3715, EMPTYLIST ) );
L5646:
        X2 = C_FIXED( STRING_LENGTH( o3715 ) );
        X3 = _TSCP( 0 );
L5648:
        X1 = CONS( X1, EMPTYLIST );
        if  ( BITAND( BITOR( _S2CINT( X2 ), _S2CINT( X3 ) ), 
                      3 ) )  goto L5650;
        if  ( EQ( _S2CUINT( X2 ), _S2CUINT( X3 ) ) )  goto L5654;
        goto L5655;
L5650:
        if  ( FALSE( scrt2__3d_2dtwo( X2, X3 ) ) )  goto L5655;
L5654:
        X4 = sc_cons( _TSCP( 8722 ), PAIR_CAR( X1 ) );
        POPSTACKTRACE( scrt1_reverse( X4 ) );
L5655:
        if  ( EQ( TSCPTAG( X3 ), FIXNUMTAG ) )  goto L5660;
        scdebug_error( c3743, 
                       c2606, CONS( X3, EMPTYLIST ) );
L5660:
        X6 = BOOLEAN( LT( _S2CINT( X3 ), 0 ) );
        if  ( TRUE( X6 ) )  goto L5666;
        X7 = C_FIXED( STRING_LENGTH( o3715 ) );
        if  ( BITAND( BITOR( _S2CINT( X3 ), _S2CINT( X7 ) ), 
                      3 ) )  goto L5670;
        if  ( GTE( _S2CINT( X3 ), _S2CINT( X7 ) ) )  goto L5666;
        goto L5677;
L5670:
        if  ( FALSE( scrt2__3e_3d_2dtwo( X3, X7 ) ) )  goto L5677;
L5666:
        scdebug_error( c3743, 
                       c2981, CONS( X3, EMPTYLIST ) );
L5677:
        X5 = C_CHAR( STRING_CHAR( o3715, X3 ) );
        X4 = BOOLEAN( EQ( _S2CUINT( X5 ), 
                          _S2CUINT( _TSCP( 23570 ) ) ) );
        if  ( TRUE( X4 ) )  goto L5682;
        X6 = BOOLEAN( LT( _S2CINT( X3 ), 0 ) );
        if  ( TRUE( X6 ) )  goto L5690;
        X7 = C_FIXED( STRING_LENGTH( o3715 ) );
        if  ( BITAND( BITOR( _S2CINT( X3 ), _S2CINT( X7 ) ), 
                      3 ) )  goto L5694;
        if  ( GTE( _S2CINT( X3 ), _S2CINT( X7 ) ) )  goto L5690;
        goto L5701;
L5694:
        if  ( FALSE( scrt2__3e_3d_2dtwo( X3, X7 ) ) )  goto L5701;
L5690:
        scdebug_error( c3743, 
                       c2981, CONS( X3, EMPTYLIST ) );
L5701:
        X5 = C_CHAR( STRING_CHAR( o3715, X3 ) );
        if  ( NEQ( _S2CUINT( X5 ), 
                   _S2CUINT( _TSCP( 8722 ) ) ) )  goto L5702;
L5682:
        X5 = sc_cons( _TSCP( 23570 ), PAIR_CAR( X1 ) );
        SETGEN( PAIR_CAR( X1 ), X5 );
L5702:
        X6 = BOOLEAN( LT( _S2CINT( X3 ), 0 ) );
        if  ( TRUE( X6 ) )  goto L5708;
        X7 = C_FIXED( STRING_LENGTH( o3715 ) );
        if  ( BITAND( BITOR( _S2CINT( X3 ), _S2CINT( X7 ) ), 
                      3 ) )  goto L5712;
        if  ( GTE( _S2CINT( X3 ), _S2CINT( X7 ) ) )  goto L5708;
        goto L5719;
L5712:
        if  ( FALSE( scrt2__3e_3d_2dtwo( X3, X7 ) ) )  goto L5719;
L5708:
        scdebug_error( c3743, 
                       c2981, CONS( X3, EMPTYLIST ) );
L5719:
        X5 = C_CHAR( STRING_CHAR( o3715, X3 ) );
        X4 = sc_cons( X5, PAIR_CAR( X1 ) );
        if  ( BITAND( BITOR( _S2CINT( X3 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L5720;
        X3 = _TSCP( IPLUS( _S2CINT( X3 ), 
                           _S2CINT( _TSCP( 4 ) ) ) );
        goto L5721;
L5720:
        X3 = scrt2__2b_2dtwo( X3, _TSCP( 4 ) );
L5721:
        X1 = X4;
        GOBACK( L5648 );
}

DEFTSCP( scrt7_readable_2dsymbol_v );
DEFCSTRING( t5722, "SCRT7_READABLE-SYMBOL" );
EXTERNTSCPP( scrt3_char_2dupper_2dcase_3f, XAL1( TSCP ) );
EXTERNTSCP( scrt3_char_2dupper_2dcase_3f_v );

TSCP  scrt7_readable_2dsymbol( o3830 )
        TSCP  o3830;
{
        TSCP  X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t5722 );
        o3830 = CONS( o3830, EMPTYLIST );
        X2 = PAIR_CAR( o3830 );
        if  ( AND( EQ( TSCPTAG( X2 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X2 ), SYMBOLTAG ) ) )  goto L5725;
        scdebug_error( c3422, 
                       c3423, CONS( X2, EMPTYLIST ) );
L5725:
        X1 = SYMBOL_NAME( X2 );
        SETGEN( PAIR_CAR( o3830 ), X1 );
        X1 = EMPTYLIST;
        X3 = PAIR_CAR( o3830 );
        if  ( AND( EQ( TSCPTAG( X3 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X3 ), STRINGTAG ) ) )  goto L5729;
        scdebug_error( c3257, 
                       c3258, CONS( X3, EMPTYLIST ) );
L5729:
        X2 = C_FIXED( STRING_LENGTH( X3 ) );
        X3 = _TSCP( 0 );
L5731:
        X1 = CONS( X1, EMPTYLIST );
        if  ( BITAND( BITOR( _S2CINT( X3 ), _S2CINT( X2 ) ), 
                      3 ) )  goto L5733;
        if  ( EQ( _S2CUINT( X3 ), _S2CUINT( X2 ) ) )  goto L5737;
        goto L5738;
L5733:
        if  ( FALSE( scrt2__3d_2dtwo( X3, X2 ) ) )  goto L5738;
L5737:
        POPSTACKTRACE( scrt1_reverse( PAIR_CAR( X1 ) ) );
L5738:
        X5 = PAIR_CAR( o3830 );
        if  ( EQ( TSCPTAG( X3 ), FIXNUMTAG ) )  goto L5743;
        scdebug_error( c3743, 
                       c2606, CONS( X3, EMPTYLIST ) );
L5743:
        X6 = BOOLEAN( LT( _S2CINT( X3 ), 0 ) );
        if  ( TRUE( X6 ) )  goto L5749;
        if  ( AND( EQ( TSCPTAG( X5 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X5 ), STRINGTAG ) ) )  goto L5751;
        scdebug_error( c3257, 
                       c3258, CONS( X5, EMPTYLIST ) );
L5751:
        X7 = C_FIXED( STRING_LENGTH( X5 ) );
        if  ( BITAND( BITOR( _S2CINT( X3 ), _S2CINT( X7 ) ), 
                      3 ) )  goto L5755;
        if  ( GTE( _S2CINT( X3 ), _S2CINT( X7 ) ) )  goto L5749;
        goto L5762;
L5755:
        if  ( FALSE( scrt2__3e_3d_2dtwo( X3, X7 ) ) )  goto L5762;
L5749:
        scdebug_error( c3743, 
                       c2981, CONS( X3, EMPTYLIST ) );
L5762:
        X4 = C_CHAR( STRING_CHAR( X5, X3 ) );
        if  ( FALSE( scrt3_char_2dalphabetic_3f( X4 ) ) )  goto L5764;
        if  ( FALSE( scrt3_char_2dupper_2dcase_3f( X4 ) ) )  goto L5766;
        X5 = FALSEVALUE;
        goto L5765;
L5766:
        X5 = TRUEVALUE;
        goto L5765;
L5764:
        X5 = TRUEVALUE;
L5765:
        if  ( FALSE( X5 ) )  goto L5788;
        if  ( FALSE( scrt1_memq( X4, c2228 ) ) )  goto L5772;
        X6 = FALSEVALUE;
        goto L5773;
L5772:
        X6 = TRUEVALUE;
L5773:
        if  ( FALSE( X6 ) )  goto L5788;
        if  ( FALSE( scrt1_memq( X4, c3872 ) ) )  goto L5778;
        X7 = FALSEVALUE;
        goto L5779;
L5778:
        X7 = TRUEVALUE;
L5779:
        if  ( FALSE( X7 ) )  goto L5788;
        if  ( TRUE( scrt3_char_2dnumeric_3f( X4 ) ) )  goto L5788;
        X8 = sc_cons( _TSCP( 23570 ), PAIR_CAR( X1 ) );
        SETGEN( PAIR_CAR( X1 ), X8 );
        goto L5796;
L5788:
        if  ( NEQ( _S2CUINT( X3 ), _S2CUINT( _TSCP( 0 ) ) ) )  goto L5796;
        if  ( TRUE( scrt3_char_2dalphabetic_3f( X4 ) ) )  goto L5796;
        if  ( TRUE( scrt1_memq( X4, c2228 ) ) )  goto L5796;
        X5 = sc_cons( _TSCP( 23570 ), PAIR_CAR( X1 ) );
        SETGEN( PAIR_CAR( X1 ), X5 );
L5796:
        X6 = PAIR_CAR( o3830 );
        X7 = BOOLEAN( LT( _S2CINT( X3 ), 0 ) );
        if  ( TRUE( X7 ) )  goto L5803;
        if  ( AND( EQ( TSCPTAG( X6 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X6 ), STRINGTAG ) ) )  goto L5805;
        scdebug_error( c3257, 
                       c3258, CONS( X6, EMPTYLIST ) );
L5805:
        X8 = C_FIXED( STRING_LENGTH( X6 ) );
        if  ( BITAND( BITOR( _S2CINT( X3 ), _S2CINT( X8 ) ), 
                      3 ) )  goto L5809;
        if  ( GTE( _S2CINT( X3 ), _S2CINT( X8 ) ) )  goto L5803;
        goto L5816;
L5809:
        if  ( FALSE( scrt2__3e_3d_2dtwo( X3, X8 ) ) )  goto L5816;
L5803:
        scdebug_error( c3743, 
                       c2981, CONS( X3, EMPTYLIST ) );
L5816:
        X5 = C_CHAR( STRING_CHAR( X6, X3 ) );
        X4 = sc_cons( X5, PAIR_CAR( X1 ) );
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 4 ) ), 
                             _S2CINT( X3 ) ), 
                      3 ) )  goto L5817;
        X3 = _TSCP( IPLUS( _S2CINT( _TSCP( 4 ) ), 
                           _S2CINT( X3 ) ) );
        goto L5818;
L5817:
        X3 = scrt2__2b_2dtwo( _TSCP( 4 ), X3 );
L5818:
        X1 = X4;
        GOBACK( L5731 );
}

DEFTSCP( scrt7_fixed_2d_3eclist_v );
DEFCSTRING( t5819, "SCRT7_FIXED->CLIST" );
EXTERNTSCPP( scrt2_remainder, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2_remainder_v );
EXTERNTSCPP( scrt2_abs, XAL1( TSCP ) );
EXTERNTSCP( scrt2_abs_v );

TSCP  scrt7_fixed_2d_3eclist( o3954 )
        TSCP  o3954;
{
        TSCP  X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t5819 );
        X1 = EMPTYLIST;
        X2 = o3954;
L5822:
        if  ( NEQ( TSCPTAG( X2 ), FIXNUMTAG ) )  goto L5823;
        X3 = BOOLEAN( EQ( _S2CUINT( X2 ), 
                          _S2CUINT( _TSCP( 0 ) ) ) );
        goto L5824;
L5823:
        X3 = scrt2_zero_3f( X2 );
L5824:
        if  ( FALSE( X3 ) )  goto L5839;
        if  ( FALSE( X1 ) )  goto L5839;
        if  ( BITAND( BITOR( _S2CINT( o3954 ), 
                             _S2CINT( _TSCP( 0 ) ) ), 
                      3 ) )  goto L5832;
        if  ( LT( _S2CINT( o3954 ), _S2CINT( _TSCP( 0 ) ) ) )  goto L5836;
        POPSTACKTRACE( X1 );
L5832:
        if  ( TRUE( scrt2__3c_2dtwo( o3954, _TSCP( 0 ) ) ) )  goto L5836;
        POPSTACKTRACE( X1 );
L5839:
        X8 = BOOLEAN( NOT( BITAND( BITOR( _S2CINT( X2 ), 
                                          _S2CINT( _TSCP( 40 ) ) ), 
                                   3 ) ) );
        if  ( FALSE( X8 ) )  goto L5846;
        if  ( EQ( _S2CUINT( _TSCP( 40 ) ), 
                  _S2CUINT( _TSCP( 0 ) ) ) )  goto L5846;
        X7 = _TSCP( REMAINDER( _S2CINT( X2 ), 
                               _S2CINT( _TSCP( 40 ) ) ) );
        goto L5847;
L5846:
        X7 = scrt2_remainder( X2, _TSCP( 40 ) );
L5847:
        if  ( NEQ( TSCPTAG( X7 ), FIXNUMTAG ) )  goto L5849;
        if  ( LT( _S2CINT( X7 ), 0 ) )  goto L5854;
        X6 = X7;
        goto L5855;
L5849:
        X6 = scrt2_abs( X7 );
        goto L5855;
L5854:
        X6 = _TSCP( INEGATE( _S2CINT( X7 ) ) );
L5855:
        X7 = C_FIXED( CHAR_C( _TSCP( 12306 ) ) );
        if  ( BITAND( BITOR( _S2CINT( X7 ), _S2CINT( X6 ) ), 
                      3 ) )  goto L5857;
        X5 = _TSCP( IPLUS( _S2CINT( X7 ), _S2CINT( X6 ) ) );
        goto L5858;
L5857:
        X5 = scrt2__2b_2dtwo( X7, X6 );
L5858:
        X6 = BOOLEAN( NEQ( TSCPTAG( X5 ), FIXNUMTAG ) );
        if  ( TRUE( X6 ) )  goto L5864;
        if  ( BITAND( BITOR( _S2CINT( X5 ), 
                             _S2CINT( _TSCP( 0 ) ) ), 
                      3 ) )  goto L5865;
        X7 = BOOLEAN( LT( _S2CINT( X5 ), 
                          _S2CINT( _TSCP( 0 ) ) ) );
        goto L5866;
L5865:
        X7 = scrt2__3c_2dtwo( X5, _TSCP( 0 ) );
L5866:
        if  ( TRUE( X7 ) )  goto L5864;
        if  ( BITAND( BITOR( _S2CINT( X5 ), 
                             _S2CINT( _TSCP( 1020 ) ) ), 
                      3 ) )  goto L5873;
        if  ( GT( _S2CINT( X5 ), _S2CINT( _TSCP( 1020 ) ) ) )  goto L5864;
        goto L5880;
L5873:
        if  ( FALSE( scrt2__3e_2dtwo( X5, _TSCP( 1020 ) ) ) )  goto L5880;
L5864:
        scdebug_error( c2455, 
                       c2456, CONS( X5, EMPTYLIST ) );
L5880:
        X4 = FIX_CHAR( X5 );
        X3 = sc_cons( X4, X1 );
        X4 = BOOLEAN( NOT( BITAND( BITOR( _S2CINT( X2 ), 
                                          _S2CINT( _TSCP( 40 ) ) ), 
                                   3 ) ) );
        if  ( FALSE( X4 ) )  goto L5887;
        if  ( EQ( _S2CUINT( _TSCP( 40 ) ), 
                  _S2CUINT( _TSCP( 0 ) ) ) )  goto L5887;
        X2 = C_FIXED( QUOTIENT( _S2CINT( X2 ), 
                                _S2CINT( _TSCP( 40 ) ) ) );
        goto L5888;
L5887:
        X2 = scrt2_quotient( X2, _TSCP( 40 ) );
L5888:
        X1 = X3;
        GOBACK( L5822 );
L5836:
        POPSTACKTRACE( sc_cons( _TSCP( 11538 ), X1 ) );
}

DEFTSCP( scrt7_float_2d_3estring_v );
DEFCSTRING( t5889, "SCRT7_FLOAT->STRING" );
EXTERNTSCPP( sc_formatnumber, XAL3( TSCP, TSCP, TSCP ) );
EXTERNTSCP( sc_formatnumber_v );
EXTERNTSCPP( scrt3_string_2dappend, XAL1( TSCP ) );
EXTERNTSCP( scrt3_string_2dappend_v );

TSCP  scrt7_float_2d_3estring( o4050 )
        TSCP  o4050;
{
        TSCP  X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t5889 );
        X1 = sc_formatnumber( o4050, _TSCP( 12 ), _TSCP( 64 ) );
        if  ( AND( EQ( TSCPTAG( X1 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X1 ), STRINGTAG ) ) )  goto L5893;
        scdebug_error( c3257, 
                       c3258, CONS( X1, EMPTYLIST ) );
L5893:
        X3 = C_FIXED( STRING_LENGTH( X1 ) );
        if  ( BITAND( BITOR( _S2CINT( X3 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L5896;
        X2 = _TSCP( IDIFFERENCE( _S2CINT( X3 ), 
                                 _S2CINT( _TSCP( 4 ) ) ) );
        goto L5897;
L5896:
        X2 = scrt2__2d_2dtwo( X3, _TSCP( 4 ) );
L5897:
        X3 = X2;
L5900:
        if  ( BITAND( BITOR( _S2CINT( X3 ), 
                             _S2CINT( _TSCP( 0 ) ) ), 
                      3 ) )  goto L5902;
        if  ( LT( _S2CINT( X3 ), _S2CINT( _TSCP( 0 ) ) ) )  goto L5906;
        goto L5907;
L5902:
        if  ( FALSE( scrt2__3c_2dtwo( X3, _TSCP( 0 ) ) ) )  goto L5907;
L5906:
        X4 = CONS( c4097, EMPTYLIST );
        POPSTACKTRACE( scrt3_string_2dappend( CONS( X1, X4 ) ) );
L5907:
        if  ( EQ( TSCPTAG( X3 ), FIXNUMTAG ) )  goto L5913;
        scdebug_error( c3743, 
                       c2606, CONS( X3, EMPTYLIST ) );
L5913:
        X5 = BOOLEAN( LT( _S2CINT( X3 ), 0 ) );
        if  ( TRUE( X5 ) )  goto L5919;
        X6 = C_FIXED( STRING_LENGTH( X1 ) );
        if  ( BITAND( BITOR( _S2CINT( X3 ), _S2CINT( X6 ) ), 
                      3 ) )  goto L5923;
        if  ( GTE( _S2CINT( X3 ), _S2CINT( X6 ) ) )  goto L5919;
        goto L5930;
L5923:
        if  ( FALSE( scrt2__3e_3d_2dtwo( X3, X6 ) ) )  goto L5930;
L5919:
        scdebug_error( c3743, 
                       c2981, CONS( X3, EMPTYLIST ) );
L5930:
        X4 = C_CHAR( STRING_CHAR( X1, X3 ) );
        if  ( TRUE( scrt1_memq( X4, c4090 ) ) )  goto L5910;
        if  ( BITAND( BITOR( _S2CINT( X3 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L5931;
        X3 = _TSCP( IDIFFERENCE( _S2CINT( X3 ), 
                                 _S2CINT( _TSCP( 4 ) ) ) );
        GOBACK( L5900 );
L5931:
        X3 = scrt2__2d_2dtwo( X3, _TSCP( 4 ) );
        GOBACK( L5900 );
L5910:
        POPSTACKTRACE( X1 );
}

void scrt2__init();
void scrt1__init();
void scrt4__init();
void scrt3__init();
void scdebug__init();
void scrt6__init();

static void  init_modules( compiler_version )
        char *compiler_version;
{
        scrt2__init();
        scrt1__init();
        scrt4__init();
        scrt3__init();
        scdebug__init();
        scrt6__init();
        MAXDISPLAY( 1 );
}

void  scrt7__init()
{
        TSCP  X7, X6, X5, X4, X3, X2, X1;

        static int  init = 0;
        if  (init)  return;
        init = 1;
        INITHEAP( 0, 0, 0, 0 );
        init_constants();
        init_modules( "(scrt7 SCHEME->C COMPILER 15mar93jfb)" );
        sc_segv__handlers();
        INITIALIZEVAR( t4616, 
                       ADR( scrt7_token_2dleft_2dparen_v ), 
                       sc_cons( c2131, EMPTYLIST ) );
        INITIALIZEVAR( t4617, 
                       ADR( scrt7_token_2dright_2dparen_v ), 
                       sc_cons( c2133, EMPTYLIST ) );
        INITIALIZEVAR( t4618, 
                       ADR( scrt7_token_2dquote_v ), 
                       sc_cons( c2135, EMPTYLIST ) );
        INITIALIZEVAR( t4619, 
                       ADR( scrt7_token_2dquasiquote_v ), 
                       sc_cons( c2137, EMPTYLIST ) );
        INITIALIZEVAR( t4620, 
                       ADR( scrt7_2dsplicing_542533dd_v ), 
                       sc_cons( c2139, EMPTYLIST ) );
        INITIALIZEVAR( t4621, 
                       ADR( scrt7_token_2dunquote_v ), 
                       sc_cons( c2141, EMPTYLIST ) );
        INITIALIZEVAR( t4622, 
                       ADR( scrt7_token_2dperiod_v ), 
                       sc_cons( c2143, EMPTYLIST ) );
        INITIALIZEVAR( t4623, 
                       ADR( scrt7_token_2dvector_v ), 
                       sc_cons( c2145, EMPTYLIST ) );
        INITIALIZEVAR( t4624, 
                       ADR( scrt7_token_2drecord_v ), 
                       sc_cons( c2147, EMPTYLIST ) );
        INITIALIZEVAR( t4625, 
                       ADR( scrt7_peek_2dchar_2dport_v ), 
                       EMPTYLIST );
        INITIALIZEVAR( t4626, 
                       ADR( scrt7_read_2dchar_2dport_v ), 
                       EMPTYLIST );
        INITIALIZEVAR( t4627, 
                       ADR( scrt7_ort_2dproc_ae18f815_v ), 
                       EMPTYLIST );
        INITIALIZEVAR( t4628, 
                       ADR( scrt7_next_2dchar_v ), 
                       MAKEPROCEDURE( 0, 
                                      0, 
                                      scrt7_next_2dchar, EMPTYLIST ) );
        INITIALIZEVAR( t4633, 
                       ADR( scrt7_token_v ), 
                       MAKEPROCEDURE( 0, 
                                      0, scrt7_token, EMPTYLIST ) );
        INITIALIZEVAR( t4768, 
                       ADR( scrt7_delimiter_3f_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      scrt7_delimiter_3f, EMPTYLIST ) );
        INITIALIZEVAR( t4775, 
                       ADR( scrt7_comment_3f_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      scrt7_comment_3f, EMPTYLIST ) );
        INITIALIZEVAR( t4789, 
                       ADR( scrt7_read_2dstring_v ), 
                       MAKEPROCEDURE( 0, 
                                      0, 
                                      scrt7_read_2dstring, EMPTYLIST ) );
        INITIALIZEVAR( t4804, 
                       ADR( scrt7_character_v ), 
                       MAKEPROCEDURE( 0, 
                                      0, 
                                      scrt7_character, EMPTYLIST ) );
        X1 = sc_make_2dvector( _TSCP( 1024 ), 
                               CONS( FALSEVALUE, EMPTYLIST ) );
        X2 = C_FIXED( CHAR_C( _TSCP( 16658 ) ) );
        X3 = C_FIXED( CHAR_C( _TSCP( 23058 ) ) );
L4959:
        if  ( BITAND( BITOR( _S2CINT( X2 ), _S2CINT( X3 ) ), 
                      3 ) )  goto L4961;
        if  ( LTE( _S2CINT( X2 ), _S2CINT( X3 ) ) )  goto L4965;
        goto L4968;
L4961:
        if  ( TRUE( scrt2__3e_2dtwo( X2, X3 ) ) )  goto L4968;
L4965:
        X5 = BOOLEAN( NEQ( TSCPTAG( X2 ), FIXNUMTAG ) );
        if  ( TRUE( X5 ) )  goto L4975;
        if  ( BITAND( BITOR( _S2CINT( X2 ), 
                             _S2CINT( _TSCP( 0 ) ) ), 
                      3 ) )  goto L4976;
        X6 = BOOLEAN( LT( _S2CINT( X2 ), 
                          _S2CINT( _TSCP( 0 ) ) ) );
        goto L4977;
L4976:
        X6 = scrt2__3c_2dtwo( X2, _TSCP( 0 ) );
L4977:
        if  ( TRUE( X6 ) )  goto L4975;
        if  ( BITAND( BITOR( _S2CINT( X2 ), 
                             _S2CINT( _TSCP( 1020 ) ) ), 
                      3 ) )  goto L4984;
        if  ( GT( _S2CINT( X2 ), _S2CINT( _TSCP( 1020 ) ) ) )  goto L4975;
        goto L4991;
L4984:
        if  ( FALSE( scrt2__3e_2dtwo( X2, _TSCP( 1020 ) ) ) )  goto L4991;
L4975:
        scdebug_error( c2455, 
                       c2456, CONS( X2, EMPTYLIST ) );
L4991:
        X4 = FIX_CHAR( X2 );
        if  ( AND( EQ( TSCPTAG( X1 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X1 ), VECTORTAG ) ) )  goto L4993;
        scdebug_error( c2602, 
                       c2603, CONS( X1, EMPTYLIST ) );
L4993:
        if  ( EQ( TSCPTAG( X2 ), FIXNUMTAG ) )  goto L4995;
        scdebug_error( c2602, 
                       c2606, CONS( X2, EMPTYLIST ) );
L4995:
        if  ( LT( _S2CUINT( FIXED_C( X2 ) ), 
                  _S2CUINT( VECTOR_LENGTH( X1 ) ) ) )  goto L4997;
        scdebug_error( c2602, 
                       c2610, CONS( X2, EMPTYLIST ) );
L4997:
        SETGEN( VECTOR_ELEMENT( X1, X2 ), X4 );
        if  ( BITAND( BITOR( _S2CINT( X2 ), 
                             _S2CINT( _TSCP( 128 ) ) ), 
                      3 ) )  goto L4999;
        X4 = _TSCP( IPLUS( _S2CINT( X2 ), 
                           _S2CINT( _TSCP( 128 ) ) ) );
        goto L5000;
L4999:
        X4 = scrt2__2b_2dtwo( X2, _TSCP( 128 ) );
L5000:
        X6 = BOOLEAN( NEQ( TSCPTAG( X2 ), FIXNUMTAG ) );
        if  ( TRUE( X6 ) )  goto L5006;
        if  ( BITAND( BITOR( _S2CINT( X2 ), 
                             _S2CINT( _TSCP( 0 ) ) ), 
                      3 ) )  goto L5007;
        X7 = BOOLEAN( LT( _S2CINT( X2 ), 
                          _S2CINT( _TSCP( 0 ) ) ) );
        goto L5008;
L5007:
        X7 = scrt2__3c_2dtwo( X2, _TSCP( 0 ) );
L5008:
        if  ( TRUE( X7 ) )  goto L5006;
        if  ( BITAND( BITOR( _S2CINT( X2 ), 
                             _S2CINT( _TSCP( 1020 ) ) ), 
                      3 ) )  goto L5015;
        if  ( GT( _S2CINT( X2 ), _S2CINT( _TSCP( 1020 ) ) ) )  goto L5006;
        goto L5022;
L5015:
        if  ( FALSE( scrt2__3e_2dtwo( X2, _TSCP( 1020 ) ) ) )  goto L5022;
L5006:
        scdebug_error( c2455, 
                       c2456, CONS( X2, EMPTYLIST ) );
L5022:
        X5 = FIX_CHAR( X2 );
        if  ( EQ( TSCPTAG( X4 ), FIXNUMTAG ) )  goto L5024;
        scdebug_error( c2602, 
                       c2606, CONS( X4, EMPTYLIST ) );
L5024:
        if  ( LT( _S2CUINT( FIXED_C( X4 ) ), 
                  _S2CUINT( VECTOR_LENGTH( X1 ) ) ) )  goto L5026;
        scdebug_error( c2602, 
                       c2610, CONS( X4, EMPTYLIST ) );
L5026:
        SETGEN( VECTOR_ELEMENT( X1, X4 ), X5 );
        if  ( BITAND( BITOR( _S2CINT( X2 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L5028;
        X4 = _TSCP( IPLUS( _S2CINT( X2 ), 
                           _S2CINT( _TSCP( 4 ) ) ) );
        goto L5029;
L5028:
        X4 = scrt2__2b_2dtwo( X2, _TSCP( 4 ) );
L5029:
        X2 = X4;
        GOBACK( L4959 );
L4968:
        X2 = c2724;
L5031:
        if  ( EQ( _S2CUINT( X2 ), _S2CUINT( EMPTYLIST ) ) )  goto L5032;
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L5036;
        scrt1__24__car_2derror( X2 );
L5036:
        X3 = PAIR_CAR( X2 );
        X4 = C_FIXED( CHAR_C( X3 ) );
        if  ( AND( EQ( TSCPTAG( X1 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X1 ), VECTORTAG ) ) )  goto L5040;
        scdebug_error( c2602, 
                       c2603, CONS( X1, EMPTYLIST ) );
L5040:
        if  ( EQ( TSCPTAG( X4 ), FIXNUMTAG ) )  goto L5042;
        scdebug_error( c2602, 
                       c2606, CONS( X4, EMPTYLIST ) );
L5042:
        if  ( LT( _S2CUINT( FIXED_C( X4 ) ), 
                  _S2CUINT( VECTOR_LENGTH( X1 ) ) ) )  goto L5044;
        scdebug_error( c2602, 
                       c2610, CONS( X4, EMPTYLIST ) );
L5044:
        SETGEN( VECTOR_ELEMENT( X1, X4 ), X3 );
        X2 = PAIR_CDR( X2 );
        GOBACK( L5031 );
L5032:
        X2 = C_FIXED( CHAR_C( _TSCP( 23570 ) ) );
        if  ( AND( EQ( TSCPTAG( X1 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X1 ), VECTORTAG ) ) )  goto L5048;
        scdebug_error( c2602, 
                       c2603, CONS( X1, EMPTYLIST ) );
L5048:
        if  ( EQ( TSCPTAG( X2 ), FIXNUMTAG ) )  goto L5050;
        scdebug_error( c2602, 
                       c2606, CONS( X2, EMPTYLIST ) );
L5050:
        if  ( LT( _S2CUINT( FIXED_C( X2 ) ), 
                  _S2CUINT( VECTOR_LENGTH( X1 ) ) ) )  goto L5052;
        scdebug_error( c2602, 
                       c2610, CONS( X2, EMPTYLIST ) );
L5052:
        SETGEN( VECTOR_ELEMENT( X1, X2 ), TRUEVALUE );
        INITIALIZEVAR( t4956, ADR( scrt7_idtable_v ), X1 );
        INITIALIZEVAR( t5054, 
                       ADR( scrt7_identifier_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      scrt7_identifier, EMPTYLIST ) );
        INITIALIZEVAR( t5077, 
                       ADR( scrt7_maxintf_v ), 
                       DOUBLE_TSCP( MAXTSCPINTF ) );
        INITIALIZEVAR( t5078, 
                       ADR( scrt7_minintf_v ), 
                       DOUBLE_TSCP( MINTSCPINTF ) );
        INITIALIZEVAR( t5079, 
                       ADR( scrt7_number_v ), 
                       MAKEPROCEDURE( 3, 
                                      0, scrt7_number, EMPTYLIST ) );
        X3 = scrt7_maxintf_v;
        if  ( AND( EQ( TSCPTAG( X3 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X3 ), DOUBLEFLOATTAG ) )
            )  goto L5227;
        scdebug_error( c2975, 
                       c2976, CONS( X3, EMPTYLIST ) );
L5227:
        X4 = BOOLEAN( LT( FLOAT_VALUE( X3 ), MINTSCPINTF ) );
        if  ( TRUE( X4 ) )  goto L5233;
        if  ( LTE( FLOAT_VALUE( X3 ), MAXTSCPINTF ) )  goto L5236;
L5233:
        scdebug_error( c2975, 
                       c2981, CONS( X3, EMPTYLIST ) );
L5236:
        X2 = FLT_FIX( X3 );
        if  ( BITAND( BITOR( _S2CINT( X2 ), 
                             _S2CINT( _TSCP( 60 ) ) ), 
                      3 ) )  goto L5238;
        X1 = _TSCP( IDIFFERENCE( _S2CINT( X2 ), 
                                 _S2CINT( _TSCP( 60 ) ) ) );
        goto L5239;
L5238:
        X1 = scrt2__2d_2dtwo( X2, _TSCP( 60 ) );
L5239:
        X3 = BOOLEAN( NOT( BITAND( BITOR( _S2CINT( X1 ), 
                                          _S2CINT( _TSCP( 64 ) ) ), 
                                   3 ) ) );
        if  ( FALSE( X3 ) )  goto L5247;
        if  ( EQ( _S2CUINT( _TSCP( 64 ) ), 
                  _S2CUINT( _TSCP( 0 ) ) ) )  goto L5247;
        X2 = C_FIXED( QUOTIENT( _S2CINT( X1 ), 
                                _S2CINT( _TSCP( 64 ) ) ) );
        goto L5248;
L5247:
        X2 = scrt2_quotient( X1, _TSCP( 64 ) );
L5248:
        INITIALIZEVAR( t5225, 
                       ADR( scrt7_max_2daccv_2dvalue_v ), X2 );
        INITIALIZEVAR( t5249, 
                       ADR( scrt7_accv_v ), 
                       MAKEPROCEDURE( 3, 
                                      0, scrt7_accv, EMPTYLIST ) );
        INITIALIZEVAR( t5298, 
                       ADR( scrt7_read_2ddatum_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      scrt7_read_2ddatum, EMPTYLIST ) );
        INITIALIZEVAR( t5323, 
                       ADR( scrt7_datum_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, scrt7_datum, EMPTYLIST ) );
        INITIALIZEVAR( t5345, 
                       ADR( scrt7_datum_2dlist_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      scrt7_datum_2dlist, EMPTYLIST ) );
        INITIALIZEVAR( t5354, 
                       ADR( scrt7_datum_2dvector_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      scrt7_datum_2dvector, EMPTYLIST ) );
        INITIALIZEVAR( t5358, 
                       ADR( scrt7_write_2dtoken_2dport_v ), 
                       EMPTYLIST );
        INITIALIZEVAR( t5359, 
                       ADR( scrt7_write_2dlength_2dport_v ), 
                       FALSEVALUE );
        INITIALIZEVAR( t5360, 
                       ADR( scrt7_write_2dwidth_2dport_v ), 
                       FALSEVALUE );
        INITIALIZEVAR( t5361, 
                       ADR( scrt7_ort_2dproc_61a60f78_v ), 
                       FALSEVALUE );
        INITIALIZEVAR( t5362, 
                       ADR( scrt7_write_2fdisplay_v ), 
                       MAKEPROCEDURE( 3, 
                                      0, 
                                      scrt7_write_2fdisplay, EMPTYLIST ) );
        INITIALIZEVAR( t5370, 
                       ADR( scrt7_write_2fdisplay2_v ), 
                       MAKEPROCEDURE( 6, 
                                      0, 
                                      scrt7_write_2fdisplay2, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( t5572, 
                       ADR( scrt7_write_2fdisplay_2dlist_v ), 
                       MAKEPROCEDURE( 6, 
                                      0, 
                                      scrt7_write_2fdisplay_2dlist, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( t5617, 
                       ADR( scrt7_readable_2dchar_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      scrt7_readable_2dchar, EMPTYLIST ) );
        INITIALIZEVAR( t5642, 
                       ADR( scrt7_readable_2dstring_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      scrt7_readable_2dstring, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( t5722, 
                       ADR( scrt7_readable_2dsymbol_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      scrt7_readable_2dsymbol, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( t5819, 
                       ADR( scrt7_fixed_2d_3eclist_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      scrt7_fixed_2d_3eclist, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( t5889, 
                       ADR( scrt7_float_2d_3estring_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      scrt7_float_2d_3estring, 
                                      EMPTYLIST ) );
        return;
}
